.pf-v6-u-screen-reader {
  position: fixed;
  inset-block-start: 0;
  inset-inline-start: 0;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  white-space: nowrap;
  border: 0;
}

.pf-v6-u-visible {
  position: static;
  overflow: visible;
  clip: auto;
  white-space: normal;
  border: inherit;
}

.pf-v6-u-hidden {
  display: none !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-screen-reader-on-sm {
    position: fixed;
    inset-block-start: 0;
    inset-inline-start: 0;
    overflow: hidden;
    clip: rect(0, 0, 0, 0);
    white-space: nowrap;
    border: 0;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-visible-on-sm {
    position: static;
    overflow: visible;
    clip: auto;
    white-space: normal;
    border: inherit;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-hidden-on-sm {
    display: none !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-screen-reader-on-md {
    position: fixed;
    inset-block-start: 0;
    inset-inline-start: 0;
    overflow: hidden;
    clip: rect(0, 0, 0, 0);
    white-space: nowrap;
    border: 0;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-visible-on-md {
    position: static;
    overflow: visible;
    clip: auto;
    white-space: normal;
    border: inherit;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-hidden-on-md {
    display: none !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-screen-reader-on-lg {
    position: fixed;
    inset-block-start: 0;
    inset-inline-start: 0;
    overflow: hidden;
    clip: rect(0, 0, 0, 0);
    white-space: nowrap;
    border: 0;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-visible-on-lg {
    position: static;
    overflow: visible;
    clip: auto;
    white-space: normal;
    border: inherit;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-hidden-on-lg {
    display: none !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-screen-reader-on-xl {
    position: fixed;
    inset-block-start: 0;
    inset-inline-start: 0;
    overflow: hidden;
    clip: rect(0, 0, 0, 0);
    white-space: nowrap;
    border: 0;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-visible-on-xl {
    position: static;
    overflow: visible;
    clip: auto;
    white-space: normal;
    border: inherit;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-hidden-on-xl {
    display: none !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-screen-reader-on-2xl {
    position: fixed;
    inset-block-start: 0;
    inset-inline-start: 0;
    overflow: hidden;
    clip: rect(0, 0, 0, 0);
    white-space: nowrap;
    border: 0;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-visible-on-2xl {
    position: static;
    overflow: visible;
    clip: auto;
    white-space: normal;
    border: inherit;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-hidden-on-2xl {
    display: none !important;
  }
}

.pf-v6-u-text-align-start {
  text-align: start !important;
}

.pf-v6-u-text-align-center {
  text-align: center !important;
}

.pf-v6-u-text-align-end {
  text-align: end !important;
}

.pf-v6-u-text-align-justify {
  text-align: justify !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-text-align-start-on-sm {
    text-align: start !important;
  }
  .pf-v6-u-text-align-center-on-sm {
    text-align: center !important;
  }
  .pf-v6-u-text-align-end-on-sm {
    text-align: end !important;
  }
  .pf-v6-u-text-align-justify-on-sm {
    text-align: justify !important;
  }
}
@media screen and (min-width: 48rem) {
  .pf-v6-u-text-align-start-on-md {
    text-align: start !important;
  }
  .pf-v6-u-text-align-center-on-md {
    text-align: center !important;
  }
  .pf-v6-u-text-align-end-on-md {
    text-align: end !important;
  }
  .pf-v6-u-text-align-justify-on-md {
    text-align: justify !important;
  }
}
@media screen and (min-width: 62rem) {
  .pf-v6-u-text-align-start-on-lg {
    text-align: start !important;
  }
  .pf-v6-u-text-align-center-on-lg {
    text-align: center !important;
  }
  .pf-v6-u-text-align-end-on-lg {
    text-align: end !important;
  }
  .pf-v6-u-text-align-justify-on-lg {
    text-align: justify !important;
  }
}
@media screen and (min-width: 75rem) {
  .pf-v6-u-text-align-start-on-xl {
    text-align: start !important;
  }
  .pf-v6-u-text-align-center-on-xl {
    text-align: center !important;
  }
  .pf-v6-u-text-align-end-on-xl {
    text-align: end !important;
  }
  .pf-v6-u-text-align-justify-on-xl {
    text-align: justify !important;
  }
}
@media screen and (min-width: 90.625rem) {
  .pf-v6-u-text-align-start-on-2xl {
    text-align: start !important;
  }
  .pf-v6-u-text-align-center-on-2xl {
    text-align: center !important;
  }
  .pf-v6-u-text-align-end-on-2xl {
    text-align: end !important;
  }
  .pf-v6-u-text-align-justify-on-2xl {
    text-align: justify !important;
  }
}
.pf-v6-u-background-color-disabled {
  background-color: var(--pf-t--global--background--color--disabled--default) !important;
}

.pf-v6-u-background-color-inverse {
  background-color: var(--pf-t--global--background--color--inverse--default) !important;
}

.pf-v6-u-background-color-highlight {
  background-color: var(--pf-t--global--background--color--highlight--default) !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-background-color-disabled-on-sm {
    background-color: var(--pf-t--global--background--color--disabled--default) !important;
  }
  .pf-v6-u-background-color-inverse-on-sm {
    background-color: var(--pf-t--global--background--color--inverse--default) !important;
  }
  .pf-v6-u-background-color-highlight-on-sm {
    background-color: var(--pf-t--global--background--color--highlight--default) !important;
  }
}
@media screen and (min-width: 48rem) {
  .pf-v6-u-background-color-disabled-on-md {
    background-color: var(--pf-t--global--background--color--disabled--default) !important;
  }
  .pf-v6-u-background-color-inverse-on-md {
    background-color: var(--pf-t--global--background--color--inverse--default) !important;
  }
  .pf-v6-u-background-color-highlight-on-md {
    background-color: var(--pf-t--global--background--color--highlight--default) !important;
  }
}
@media screen and (min-width: 62rem) {
  .pf-v6-u-background-color-disabled-on-lg {
    background-color: var(--pf-t--global--background--color--disabled--default) !important;
  }
  .pf-v6-u-background-color-inverse-on-lg {
    background-color: var(--pf-t--global--background--color--inverse--default) !important;
  }
  .pf-v6-u-background-color-highlight-on-lg {
    background-color: var(--pf-t--global--background--color--highlight--default) !important;
  }
}
@media screen and (min-width: 75rem) {
  .pf-v6-u-background-color-disabled-on-xl {
    background-color: var(--pf-t--global--background--color--disabled--default) !important;
  }
  .pf-v6-u-background-color-inverse-on-xl {
    background-color: var(--pf-t--global--background--color--inverse--default) !important;
  }
  .pf-v6-u-background-color-highlight-on-xl {
    background-color: var(--pf-t--global--background--color--highlight--default) !important;
  }
}
@media screen and (min-width: 90.625rem) {
  .pf-v6-u-background-color-disabled-on-2xl {
    background-color: var(--pf-t--global--background--color--disabled--default) !important;
  }
  .pf-v6-u-background-color-inverse-on-2xl {
    background-color: var(--pf-t--global--background--color--inverse--default) !important;
  }
  .pf-v6-u-background-color-highlight-on-2xl {
    background-color: var(--pf-t--global--background--color--highlight--default) !important;
  }
}
.pf-v6-u-box-shadow-sm {
  box-shadow: var(--pf-t--global--box-shadow--sm) !important;
}

.pf-v6-u-box-shadow-sm-top {
  box-shadow: var(--pf-t--global--box-shadow--sm--top) !important;
}

.pf-v6-u-box-shadow-sm-right {
  box-shadow: var(--pf-t--global--box-shadow--sm--right) !important;
}

.pf-v6-u-box-shadow-sm-bottom {
  box-shadow: var(--pf-t--global--box-shadow--sm--bottom) !important;
}

.pf-v6-u-box-shadow-sm-left {
  box-shadow: var(--pf-t--global--box-shadow--sm--left) !important;
}

.pf-v6-u-box-shadow-md {
  box-shadow: var(--pf-t--global--box-shadow--md) !important;
}

.pf-v6-u-box-shadow-md-top {
  box-shadow: var(--pf-t--global--box-shadow--md--top) !important;
}

.pf-v6-u-box-shadow-md-right {
  box-shadow: var(--pf-t--global--box-shadow--md--right) !important;
}

.pf-v6-u-box-shadow-md-bottom {
  box-shadow: var(--pf-t--global--box-shadow--md--bottom) !important;
}

.pf-v6-u-box-shadow-md-left {
  box-shadow: var(--pf-t--global--box-shadow--md--left) !important;
}

.pf-v6-u-box-shadow-lg {
  box-shadow: var(--pf-t--global--box-shadow--lg) !important;
}

.pf-v6-u-box-shadow-lg-top {
  box-shadow: var(--pf-t--global--box-shadow--lg--top) !important;
}

.pf-v6-u-box-shadow-lg-right {
  box-shadow: var(--pf-t--global--box-shadow--lg--right) !important;
}

.pf-v6-u-box-shadow-lg-bottom {
  box-shadow: var(--pf-t--global--box-shadow--lg--bottom) !important;
}

.pf-v6-u-box-shadow-lg-left {
  box-shadow: var(--pf-t--global--box-shadow--lg--left) !important;
}

.pf-v6-u-display-none {
  display: none !important;
}

.pf-v6-u-display-inline-block {
  display: inline-block !important;
}

.pf-v6-u-display-block {
  display: block !important;
}

.pf-v6-u-display-inline {
  display: inline !important;
}

.pf-v6-u-display-table {
  display: table !important;
}

.pf-v6-u-display-table-cell {
  display: table-cell !important;
}

.pf-v6-u-display-table-row {
  display: table-row !important;
}

.pf-v6-u-display-flex {
  display: flex !important;
}

.pf-v6-u-display-inline-flex {
  display: inline-flex !important;
}

.pf-v6-u-display-grid {
  display: grid !important;
}

.pf-v6-u-display-inline-grid {
  display: inline-grid !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-display-none-on-sm {
    display: none !important;
  }
  .pf-v6-u-display-inline-block-on-sm {
    display: inline-block !important;
  }
  .pf-v6-u-display-block-on-sm {
    display: block !important;
  }
  .pf-v6-u-display-inline-on-sm {
    display: inline !important;
  }
  .pf-v6-u-display-table-on-sm {
    display: table !important;
  }
  .pf-v6-u-display-table-cell-on-sm {
    display: table-cell !important;
  }
  .pf-v6-u-display-table-row-on-sm {
    display: table-row !important;
  }
  .pf-v6-u-display-flex-on-sm {
    display: flex !important;
  }
  .pf-v6-u-display-inline-flex-on-sm {
    display: inline-flex !important;
  }
  .pf-v6-u-display-grid-on-sm {
    display: grid !important;
  }
  .pf-v6-u-display-inline-grid-on-sm {
    display: inline-grid !important;
  }
}
@media screen and (min-width: 48rem) {
  .pf-v6-u-display-none-on-md {
    display: none !important;
  }
  .pf-v6-u-display-inline-block-on-md {
    display: inline-block !important;
  }
  .pf-v6-u-display-block-on-md {
    display: block !important;
  }
  .pf-v6-u-display-inline-on-md {
    display: inline !important;
  }
  .pf-v6-u-display-table-on-md {
    display: table !important;
  }
  .pf-v6-u-display-table-cell-on-md {
    display: table-cell !important;
  }
  .pf-v6-u-display-table-row-on-md {
    display: table-row !important;
  }
  .pf-v6-u-display-flex-on-md {
    display: flex !important;
  }
  .pf-v6-u-display-inline-flex-on-md {
    display: inline-flex !important;
  }
  .pf-v6-u-display-grid-on-md {
    display: grid !important;
  }
  .pf-v6-u-display-inline-grid-on-md {
    display: inline-grid !important;
  }
}
@media screen and (min-width: 62rem) {
  .pf-v6-u-display-none-on-lg {
    display: none !important;
  }
  .pf-v6-u-display-inline-block-on-lg {
    display: inline-block !important;
  }
  .pf-v6-u-display-block-on-lg {
    display: block !important;
  }
  .pf-v6-u-display-inline-on-lg {
    display: inline !important;
  }
  .pf-v6-u-display-table-on-lg {
    display: table !important;
  }
  .pf-v6-u-display-table-cell-on-lg {
    display: table-cell !important;
  }
  .pf-v6-u-display-table-row-on-lg {
    display: table-row !important;
  }
  .pf-v6-u-display-flex-on-lg {
    display: flex !important;
  }
  .pf-v6-u-display-inline-flex-on-lg {
    display: inline-flex !important;
  }
  .pf-v6-u-display-grid-on-lg {
    display: grid !important;
  }
  .pf-v6-u-display-inline-grid-on-lg {
    display: inline-grid !important;
  }
}
@media screen and (min-width: 75rem) {
  .pf-v6-u-display-none-on-xl {
    display: none !important;
  }
  .pf-v6-u-display-inline-block-on-xl {
    display: inline-block !important;
  }
  .pf-v6-u-display-block-on-xl {
    display: block !important;
  }
  .pf-v6-u-display-inline-on-xl {
    display: inline !important;
  }
  .pf-v6-u-display-table-on-xl {
    display: table !important;
  }
  .pf-v6-u-display-table-cell-on-xl {
    display: table-cell !important;
  }
  .pf-v6-u-display-table-row-on-xl {
    display: table-row !important;
  }
  .pf-v6-u-display-flex-on-xl {
    display: flex !important;
  }
  .pf-v6-u-display-inline-flex-on-xl {
    display: inline-flex !important;
  }
  .pf-v6-u-display-grid-on-xl {
    display: grid !important;
  }
  .pf-v6-u-display-inline-grid-on-xl {
    display: inline-grid !important;
  }
}
@media screen and (min-width: 90.625rem) {
  .pf-v6-u-display-none-on-2xl {
    display: none !important;
  }
  .pf-v6-u-display-inline-block-on-2xl {
    display: inline-block !important;
  }
  .pf-v6-u-display-block-on-2xl {
    display: block !important;
  }
  .pf-v6-u-display-inline-on-2xl {
    display: inline !important;
  }
  .pf-v6-u-display-table-on-2xl {
    display: table !important;
  }
  .pf-v6-u-display-table-cell-on-2xl {
    display: table-cell !important;
  }
  .pf-v6-u-display-table-row-on-2xl {
    display: table-row !important;
  }
  .pf-v6-u-display-flex-on-2xl {
    display: flex !important;
  }
  .pf-v6-u-display-inline-flex-on-2xl {
    display: inline-flex !important;
  }
  .pf-v6-u-display-grid-on-2xl {
    display: grid !important;
  }
  .pf-v6-u-display-inline-grid-on-2xl {
    display: inline-grid !important;
  }
}
.pf-v6-u-flex-direction-column {
  flex-direction: column !important;
}

.pf-v6-u-flex-direction-column-reverse {
  flex-direction: column-reverse !important;
}

.pf-v6-u-flex-direction-row {
  flex-direction: row !important;
}

.pf-v6-u-flex-direction-row-reverse {
  flex-direction: row-reverse !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-flex-direction-column-on-sm {
    flex-direction: column !important;
  }
  .pf-v6-u-flex-direction-column-reverse-on-sm {
    flex-direction: column-reverse !important;
  }
  .pf-v6-u-flex-direction-row-on-sm {
    flex-direction: row !important;
  }
  .pf-v6-u-flex-direction-row-reverse-on-sm {
    flex-direction: row-reverse !important;
  }
}
@media screen and (min-width: 48rem) {
  .pf-v6-u-flex-direction-column-on-md {
    flex-direction: column !important;
  }
  .pf-v6-u-flex-direction-column-reverse-on-md {
    flex-direction: column-reverse !important;
  }
  .pf-v6-u-flex-direction-row-on-md {
    flex-direction: row !important;
  }
  .pf-v6-u-flex-direction-row-reverse-on-md {
    flex-direction: row-reverse !important;
  }
}
@media screen and (min-width: 62rem) {
  .pf-v6-u-flex-direction-column-on-lg {
    flex-direction: column !important;
  }
  .pf-v6-u-flex-direction-column-reverse-on-lg {
    flex-direction: column-reverse !important;
  }
  .pf-v6-u-flex-direction-row-on-lg {
    flex-direction: row !important;
  }
  .pf-v6-u-flex-direction-row-reverse-on-lg {
    flex-direction: row-reverse !important;
  }
}
@media screen and (min-width: 75rem) {
  .pf-v6-u-flex-direction-column-on-xl {
    flex-direction: column !important;
  }
  .pf-v6-u-flex-direction-column-reverse-on-xl {
    flex-direction: column-reverse !important;
  }
  .pf-v6-u-flex-direction-row-on-xl {
    flex-direction: row !important;
  }
  .pf-v6-u-flex-direction-row-reverse-on-xl {
    flex-direction: row-reverse !important;
  }
}
@media screen and (min-width: 90.625rem) {
  .pf-v6-u-flex-direction-column-on-2xl {
    flex-direction: column !important;
  }
  .pf-v6-u-flex-direction-column-reverse-on-2xl {
    flex-direction: column-reverse !important;
  }
  .pf-v6-u-flex-direction-row-on-2xl {
    flex-direction: row !important;
  }
  .pf-v6-u-flex-direction-row-reverse-on-2xl {
    flex-direction: row-reverse !important;
  }
}
.pf-v6-u-flex-wrap {
  flex-wrap: wrap !important;
}

.pf-v6-u-flex-nowrap {
  flex-wrap: nowrap !important;
}

.pf-v6-u-flex-wrap-reverse {
  flex-wrap: wrap-reverse !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-flex-wrap-on-sm {
    flex-wrap: wrap !important;
  }
  .pf-v6-u-flex-nowrap-on-sm {
    flex-wrap: nowrap !important;
  }
  .pf-v6-u-flex-wrap-reverse-on-sm {
    flex-wrap: wrap-reverse !important;
  }
}
@media screen and (min-width: 48rem) {
  .pf-v6-u-flex-wrap-on-md {
    flex-wrap: wrap !important;
  }
  .pf-v6-u-flex-nowrap-on-md {
    flex-wrap: nowrap !important;
  }
  .pf-v6-u-flex-wrap-reverse-on-md {
    flex-wrap: wrap-reverse !important;
  }
}
@media screen and (min-width: 62rem) {
  .pf-v6-u-flex-wrap-on-lg {
    flex-wrap: wrap !important;
  }
  .pf-v6-u-flex-nowrap-on-lg {
    flex-wrap: nowrap !important;
  }
  .pf-v6-u-flex-wrap-reverse-on-lg {
    flex-wrap: wrap-reverse !important;
  }
}
@media screen and (min-width: 75rem) {
  .pf-v6-u-flex-wrap-on-xl {
    flex-wrap: wrap !important;
  }
  .pf-v6-u-flex-nowrap-on-xl {
    flex-wrap: nowrap !important;
  }
  .pf-v6-u-flex-wrap-reverse-on-xl {
    flex-wrap: wrap-reverse !important;
  }
}
@media screen and (min-width: 90.625rem) {
  .pf-v6-u-flex-wrap-on-2xl {
    flex-wrap: wrap !important;
  }
  .pf-v6-u-flex-nowrap-on-2xl {
    flex-wrap: nowrap !important;
  }
  .pf-v6-u-flex-wrap-reverse-on-2xl {
    flex-wrap: wrap-reverse !important;
  }
}
.pf-v6-u-align-items-flex-start {
  align-items: flex-start !important;
}

.pf-v6-u-align-items-flex-end {
  align-items: flex-end !important;
}

.pf-v6-u-align-items-center {
  align-items: center !important;
}

.pf-v6-u-align-items-baseline {
  align-items: baseline !important;
}

.pf-v6-u-align-items-stretch {
  align-items: stretch !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-align-items-flex-start-on-sm {
    align-items: flex-start !important;
  }
  .pf-v6-u-align-items-flex-end-on-sm {
    align-items: flex-end !important;
  }
  .pf-v6-u-align-items-center-on-sm {
    align-items: center !important;
  }
  .pf-v6-u-align-items-baseline-on-sm {
    align-items: baseline !important;
  }
  .pf-v6-u-align-items-stretch-on-sm {
    align-items: stretch !important;
  }
}
@media screen and (min-width: 48rem) {
  .pf-v6-u-align-items-flex-start-on-md {
    align-items: flex-start !important;
  }
  .pf-v6-u-align-items-flex-end-on-md {
    align-items: flex-end !important;
  }
  .pf-v6-u-align-items-center-on-md {
    align-items: center !important;
  }
  .pf-v6-u-align-items-baseline-on-md {
    align-items: baseline !important;
  }
  .pf-v6-u-align-items-stretch-on-md {
    align-items: stretch !important;
  }
}
@media screen and (min-width: 62rem) {
  .pf-v6-u-align-items-flex-start-on-lg {
    align-items: flex-start !important;
  }
  .pf-v6-u-align-items-flex-end-on-lg {
    align-items: flex-end !important;
  }
  .pf-v6-u-align-items-center-on-lg {
    align-items: center !important;
  }
  .pf-v6-u-align-items-baseline-on-lg {
    align-items: baseline !important;
  }
  .pf-v6-u-align-items-stretch-on-lg {
    align-items: stretch !important;
  }
}
@media screen and (min-width: 75rem) {
  .pf-v6-u-align-items-flex-start-on-xl {
    align-items: flex-start !important;
  }
  .pf-v6-u-align-items-flex-end-on-xl {
    align-items: flex-end !important;
  }
  .pf-v6-u-align-items-center-on-xl {
    align-items: center !important;
  }
  .pf-v6-u-align-items-baseline-on-xl {
    align-items: baseline !important;
  }
  .pf-v6-u-align-items-stretch-on-xl {
    align-items: stretch !important;
  }
}
@media screen and (min-width: 90.625rem) {
  .pf-v6-u-align-items-flex-start-on-2xl {
    align-items: flex-start !important;
  }
  .pf-v6-u-align-items-flex-end-on-2xl {
    align-items: flex-end !important;
  }
  .pf-v6-u-align-items-center-on-2xl {
    align-items: center !important;
  }
  .pf-v6-u-align-items-baseline-on-2xl {
    align-items: baseline !important;
  }
  .pf-v6-u-align-items-stretch-on-2xl {
    align-items: stretch !important;
  }
}
.pf-v6-u-align-self-flex-start {
  align-self: flex-start !important;
}

.pf-v6-u-align-self-flex-end {
  align-self: flex-end !important;
}

.pf-v6-u-align-self-center {
  align-self: center !important;
}

.pf-v6-u-align-self-baseline {
  align-self: baseline !important;
}

.pf-v6-u-align-self-stretch {
  align-self: stretch !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-align-self-flex-start-on-sm {
    align-self: flex-start !important;
  }
  .pf-v6-u-align-self-flex-end-on-sm {
    align-self: flex-end !important;
  }
  .pf-v6-u-align-self-center-on-sm {
    align-self: center !important;
  }
  .pf-v6-u-align-self-baseline-on-sm {
    align-self: baseline !important;
  }
  .pf-v6-u-align-self-stretch-on-sm {
    align-self: stretch !important;
  }
}
@media screen and (min-width: 48rem) {
  .pf-v6-u-align-self-flex-start-on-md {
    align-self: flex-start !important;
  }
  .pf-v6-u-align-self-flex-end-on-md {
    align-self: flex-end !important;
  }
  .pf-v6-u-align-self-center-on-md {
    align-self: center !important;
  }
  .pf-v6-u-align-self-baseline-on-md {
    align-self: baseline !important;
  }
  .pf-v6-u-align-self-stretch-on-md {
    align-self: stretch !important;
  }
}
@media screen and (min-width: 62rem) {
  .pf-v6-u-align-self-flex-start-on-lg {
    align-self: flex-start !important;
  }
  .pf-v6-u-align-self-flex-end-on-lg {
    align-self: flex-end !important;
  }
  .pf-v6-u-align-self-center-on-lg {
    align-self: center !important;
  }
  .pf-v6-u-align-self-baseline-on-lg {
    align-self: baseline !important;
  }
  .pf-v6-u-align-self-stretch-on-lg {
    align-self: stretch !important;
  }
}
@media screen and (min-width: 75rem) {
  .pf-v6-u-align-self-flex-start-on-xl {
    align-self: flex-start !important;
  }
  .pf-v6-u-align-self-flex-end-on-xl {
    align-self: flex-end !important;
  }
  .pf-v6-u-align-self-center-on-xl {
    align-self: center !important;
  }
  .pf-v6-u-align-self-baseline-on-xl {
    align-self: baseline !important;
  }
  .pf-v6-u-align-self-stretch-on-xl {
    align-self: stretch !important;
  }
}
@media screen and (min-width: 90.625rem) {
  .pf-v6-u-align-self-flex-start-on-2xl {
    align-self: flex-start !important;
  }
  .pf-v6-u-align-self-flex-end-on-2xl {
    align-self: flex-end !important;
  }
  .pf-v6-u-align-self-center-on-2xl {
    align-self: center !important;
  }
  .pf-v6-u-align-self-baseline-on-2xl {
    align-self: baseline !important;
  }
  .pf-v6-u-align-self-stretch-on-2xl {
    align-self: stretch !important;
  }
}
.pf-v6-u-align-content-flex-start {
  align-content: flex-start !important;
}

.pf-v6-u-align-content-flex-end {
  align-content: flex-end !important;
}

.pf-v6-u-align-content-center {
  align-content: center !important;
}

.pf-v6-u-align-content-space-between {
  align-content: space-between !important;
}

.pf-v6-u-align-content-space-around {
  align-content: space-around !important;
}

.pf-v6-u-align-content-stretch {
  align-content: stretch !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-align-content-flex-start-on-sm {
    align-content: flex-start !important;
  }
  .pf-v6-u-align-content-flex-end-on-sm {
    align-content: flex-end !important;
  }
  .pf-v6-u-align-content-center-on-sm {
    align-content: center !important;
  }
  .pf-v6-u-align-content-space-between-on-sm {
    align-content: space-between !important;
  }
  .pf-v6-u-align-content-space-around-on-sm {
    align-content: space-around !important;
  }
  .pf-v6-u-align-content-stretch-on-sm {
    align-content: stretch !important;
  }
}
@media screen and (min-width: 48rem) {
  .pf-v6-u-align-content-flex-start-on-md {
    align-content: flex-start !important;
  }
  .pf-v6-u-align-content-flex-end-on-md {
    align-content: flex-end !important;
  }
  .pf-v6-u-align-content-center-on-md {
    align-content: center !important;
  }
  .pf-v6-u-align-content-space-between-on-md {
    align-content: space-between !important;
  }
  .pf-v6-u-align-content-space-around-on-md {
    align-content: space-around !important;
  }
  .pf-v6-u-align-content-stretch-on-md {
    align-content: stretch !important;
  }
}
@media screen and (min-width: 62rem) {
  .pf-v6-u-align-content-flex-start-on-lg {
    align-content: flex-start !important;
  }
  .pf-v6-u-align-content-flex-end-on-lg {
    align-content: flex-end !important;
  }
  .pf-v6-u-align-content-center-on-lg {
    align-content: center !important;
  }
  .pf-v6-u-align-content-space-between-on-lg {
    align-content: space-between !important;
  }
  .pf-v6-u-align-content-space-around-on-lg {
    align-content: space-around !important;
  }
  .pf-v6-u-align-content-stretch-on-lg {
    align-content: stretch !important;
  }
}
@media screen and (min-width: 75rem) {
  .pf-v6-u-align-content-flex-start-on-xl {
    align-content: flex-start !important;
  }
  .pf-v6-u-align-content-flex-end-on-xl {
    align-content: flex-end !important;
  }
  .pf-v6-u-align-content-center-on-xl {
    align-content: center !important;
  }
  .pf-v6-u-align-content-space-between-on-xl {
    align-content: space-between !important;
  }
  .pf-v6-u-align-content-space-around-on-xl {
    align-content: space-around !important;
  }
  .pf-v6-u-align-content-stretch-on-xl {
    align-content: stretch !important;
  }
}
@media screen and (min-width: 90.625rem) {
  .pf-v6-u-align-content-flex-start-on-2xl {
    align-content: flex-start !important;
  }
  .pf-v6-u-align-content-flex-end-on-2xl {
    align-content: flex-end !important;
  }
  .pf-v6-u-align-content-center-on-2xl {
    align-content: center !important;
  }
  .pf-v6-u-align-content-space-between-on-2xl {
    align-content: space-between !important;
  }
  .pf-v6-u-align-content-space-around-on-2xl {
    align-content: space-around !important;
  }
  .pf-v6-u-align-content-stretch-on-2xl {
    align-content: stretch !important;
  }
}
.pf-v6-u-justify-content-flex-start {
  justify-content: flex-start !important;
}

.pf-v6-u-justify-content-flex-end {
  justify-content: flex-end !important;
}

.pf-v6-u-justify-content-center {
  justify-content: center !important;
}

.pf-v6-u-justify-content-space-between {
  justify-content: space-between !important;
}

.pf-v6-u-justify-content-space-around {
  justify-content: space-around !important;
}

.pf-v6-u-justify-content-stretch {
  justify-content: stretch !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-justify-content-flex-start-on-sm {
    justify-content: flex-start !important;
  }
  .pf-v6-u-justify-content-flex-end-on-sm {
    justify-content: flex-end !important;
  }
  .pf-v6-u-justify-content-center-on-sm {
    justify-content: center !important;
  }
  .pf-v6-u-justify-content-space-between-on-sm {
    justify-content: space-between !important;
  }
  .pf-v6-u-justify-content-space-around-on-sm {
    justify-content: space-around !important;
  }
  .pf-v6-u-justify-content-stretch-on-sm {
    justify-content: stretch !important;
  }
}
@media screen and (min-width: 48rem) {
  .pf-v6-u-justify-content-flex-start-on-md {
    justify-content: flex-start !important;
  }
  .pf-v6-u-justify-content-flex-end-on-md {
    justify-content: flex-end !important;
  }
  .pf-v6-u-justify-content-center-on-md {
    justify-content: center !important;
  }
  .pf-v6-u-justify-content-space-between-on-md {
    justify-content: space-between !important;
  }
  .pf-v6-u-justify-content-space-around-on-md {
    justify-content: space-around !important;
  }
  .pf-v6-u-justify-content-stretch-on-md {
    justify-content: stretch !important;
  }
}
@media screen and (min-width: 62rem) {
  .pf-v6-u-justify-content-flex-start-on-lg {
    justify-content: flex-start !important;
  }
  .pf-v6-u-justify-content-flex-end-on-lg {
    justify-content: flex-end !important;
  }
  .pf-v6-u-justify-content-center-on-lg {
    justify-content: center !important;
  }
  .pf-v6-u-justify-content-space-between-on-lg {
    justify-content: space-between !important;
  }
  .pf-v6-u-justify-content-space-around-on-lg {
    justify-content: space-around !important;
  }
  .pf-v6-u-justify-content-stretch-on-lg {
    justify-content: stretch !important;
  }
}
@media screen and (min-width: 75rem) {
  .pf-v6-u-justify-content-flex-start-on-xl {
    justify-content: flex-start !important;
  }
  .pf-v6-u-justify-content-flex-end-on-xl {
    justify-content: flex-end !important;
  }
  .pf-v6-u-justify-content-center-on-xl {
    justify-content: center !important;
  }
  .pf-v6-u-justify-content-space-between-on-xl {
    justify-content: space-between !important;
  }
  .pf-v6-u-justify-content-space-around-on-xl {
    justify-content: space-around !important;
  }
  .pf-v6-u-justify-content-stretch-on-xl {
    justify-content: stretch !important;
  }
}
@media screen and (min-width: 90.625rem) {
  .pf-v6-u-justify-content-flex-start-on-2xl {
    justify-content: flex-start !important;
  }
  .pf-v6-u-justify-content-flex-end-on-2xl {
    justify-content: flex-end !important;
  }
  .pf-v6-u-justify-content-center-on-2xl {
    justify-content: center !important;
  }
  .pf-v6-u-justify-content-space-between-on-2xl {
    justify-content: space-between !important;
  }
  .pf-v6-u-justify-content-space-around-on-2xl {
    justify-content: space-around !important;
  }
  .pf-v6-u-justify-content-stretch-on-2xl {
    justify-content: stretch !important;
  }
}
.pf-v6-u-flex-shrink-1 {
  flex-shrink: 1 !important;
}

.pf-v6-u-flex-grow-1 {
  flex-grow: 1 !important;
}

.pf-v6-u-flex-shrink-0 {
  flex-shrink: 0 !important;
}

.pf-v6-u-flex-grow-0 {
  flex-grow: 0 !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-flex-shrink-1-on-sm {
    flex-shrink: 1 !important;
  }
  .pf-v6-u-flex-grow-1-on-sm {
    flex-grow: 1 !important;
  }
  .pf-v6-u-flex-shrink-0-on-sm {
    flex-shrink: 0 !important;
  }
  .pf-v6-u-flex-grow-0-on-sm {
    flex-grow: 0 !important;
  }
}
@media screen and (min-width: 48rem) {
  .pf-v6-u-flex-shrink-1-on-md {
    flex-shrink: 1 !important;
  }
  .pf-v6-u-flex-grow-1-on-md {
    flex-grow: 1 !important;
  }
  .pf-v6-u-flex-shrink-0-on-md {
    flex-shrink: 0 !important;
  }
  .pf-v6-u-flex-grow-0-on-md {
    flex-grow: 0 !important;
  }
}
@media screen and (min-width: 62rem) {
  .pf-v6-u-flex-shrink-1-on-lg {
    flex-shrink: 1 !important;
  }
  .pf-v6-u-flex-grow-1-on-lg {
    flex-grow: 1 !important;
  }
  .pf-v6-u-flex-shrink-0-on-lg {
    flex-shrink: 0 !important;
  }
  .pf-v6-u-flex-grow-0-on-lg {
    flex-grow: 0 !important;
  }
}
@media screen and (min-width: 75rem) {
  .pf-v6-u-flex-shrink-1-on-xl {
    flex-shrink: 1 !important;
  }
  .pf-v6-u-flex-grow-1-on-xl {
    flex-grow: 1 !important;
  }
  .pf-v6-u-flex-shrink-0-on-xl {
    flex-shrink: 0 !important;
  }
  .pf-v6-u-flex-grow-0-on-xl {
    flex-grow: 0 !important;
  }
}
@media screen and (min-width: 90.625rem) {
  .pf-v6-u-flex-shrink-1-on-2xl {
    flex-shrink: 1 !important;
  }
  .pf-v6-u-flex-grow-1-on-2xl {
    flex-grow: 1 !important;
  }
  .pf-v6-u-flex-shrink-0-on-2xl {
    flex-shrink: 0 !important;
  }
  .pf-v6-u-flex-grow-0-on-2xl {
    flex-grow: 0 !important;
  }
}
.pf-v6-u-flex-basis-0 {
  flex-basis: 0 !important;
}

.pf-v6-u-flex-basis-auto {
  flex-basis: auto !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-flex-basis-0-on-sm {
    flex-basis: 0 !important;
  }
  .pf-v6-u-flex-basis-auto-on-sm {
    flex-basis: auto !important;
  }
}
@media screen and (min-width: 48rem) {
  .pf-v6-u-flex-basis-0-on-md {
    flex-basis: 0 !important;
  }
  .pf-v6-u-flex-basis-auto-on-md {
    flex-basis: auto !important;
  }
}
@media screen and (min-width: 62rem) {
  .pf-v6-u-flex-basis-0-on-lg {
    flex-basis: 0 !important;
  }
  .pf-v6-u-flex-basis-auto-on-lg {
    flex-basis: auto !important;
  }
}
@media screen and (min-width: 75rem) {
  .pf-v6-u-flex-basis-0-on-xl {
    flex-basis: 0 !important;
  }
  .pf-v6-u-flex-basis-auto-on-xl {
    flex-basis: auto !important;
  }
}
@media screen and (min-width: 90.625rem) {
  .pf-v6-u-flex-basis-0-on-2xl {
    flex-basis: 0 !important;
  }
  .pf-v6-u-flex-basis-auto-on-2xl {
    flex-basis: auto !important;
  }
}
.pf-v6-u-flex-none {
  flex: none !important;
}

.pf-v6-u-flex-1 {
  flex: 1 !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-flex-none-on-sm {
    flex: none !important;
  }
  .pf-v6-u-flex-1-on-sm {
    flex: 1 !important;
  }
}
@media screen and (min-width: 48rem) {
  .pf-v6-u-flex-none-on-md {
    flex: none !important;
  }
  .pf-v6-u-flex-1-on-md {
    flex: 1 !important;
  }
}
@media screen and (min-width: 62rem) {
  .pf-v6-u-flex-none-on-lg {
    flex: none !important;
  }
  .pf-v6-u-flex-1-on-lg {
    flex: 1 !important;
  }
}
@media screen and (min-width: 75rem) {
  .pf-v6-u-flex-none-on-xl {
    flex: none !important;
  }
  .pf-v6-u-flex-1-on-xl {
    flex: 1 !important;
  }
}
@media screen and (min-width: 90.625rem) {
  .pf-v6-u-flex-none-on-2xl {
    flex: none !important;
  }
  .pf-v6-u-flex-1-on-2xl {
    flex: 1 !important;
  }
}
.pf-v6-u-flex-fill {
  flex: 1 1 auto !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-flex-fill-on-sm {
    flex: 1 1 auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-flex-fill-on-md {
    flex: 1 1 auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-flex-fill-on-lg {
    flex: 1 1 auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-flex-fill-on-xl {
    flex: 1 1 auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-flex-fill-on-2xl {
    flex: 1 1 auto !important;
  }
}

.pf-v6-u-float-inline-start {
  float: inline-start !important;
}

.pf-v6-u-float-inline-end {
  float: inline-end !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-float-inline-start-on-sm {
    float: inline-start !important;
  }
  .pf-v6-u-float-inline-end-on-sm {
    float: inline-end !important;
  }
}
@media screen and (min-width: 48rem) {
  .pf-v6-u-float-inline-start-on-md {
    float: inline-start !important;
  }
  .pf-v6-u-float-inline-end-on-md {
    float: inline-end !important;
  }
}
@media screen and (min-width: 62rem) {
  .pf-v6-u-float-inline-start-on-lg {
    float: inline-start !important;
  }
  .pf-v6-u-float-inline-end-on-lg {
    float: inline-end !important;
  }
}
@media screen and (min-width: 75rem) {
  .pf-v6-u-float-inline-start-on-xl {
    float: inline-start !important;
  }
  .pf-v6-u-float-inline-end-on-xl {
    float: inline-end !important;
  }
}
@media screen and (min-width: 90.625rem) {
  .pf-v6-u-float-inline-start-on-2xl {
    float: inline-start !important;
  }
  .pf-v6-u-float-inline-end-on-2xl {
    float: inline-end !important;
  }
}
.pf-v6-u-w-auto {
  width: auto !important;
}

.pf-v6-u-w-initial {
  width: initial !important;
}

.pf-v6-u-w-inherit {
  width: inherit !important;
}

.pf-v6-u-w-0 {
  width: 0% !important;
}

.pf-v6-u-w-25 {
  width: 25% !important;
}

.pf-v6-u-w-33 {
  width: 33.3333333333% !important;
}

.pf-v6-u-w-50 {
  width: 50% !important;
}

.pf-v6-u-w-66 {
  width: 66.6666666667% !important;
}

.pf-v6-u-w-75 {
  width: 75% !important;
}

.pf-v6-u-w-100 {
  width: 100% !important;
}

.pf-v6-u-w-25vw {
  width: 25vw !important;
}

.pf-v6-u-w-33vw {
  width: 33.3333333333vw !important;
}

.pf-v6-u-w-50vw {
  width: 50vw !important;
}

.pf-v6-u-w-66vw {
  width: 66.6666666667vw !important;
}

.pf-v6-u-w-75vw {
  width: 75vw !important;
}

.pf-v6-u-w-100vw {
  width: 100vw !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-w-auto-on-sm {
    width: auto !important;
  }
  .pf-v6-u-w-initial-on-sm {
    width: initial !important;
  }
  .pf-v6-u-w-inherit-on-sm {
    width: inherit !important;
  }
  .pf-v6-u-w-0-on-sm {
    width: 0% !important;
  }
  .pf-v6-u-w-25-on-sm {
    width: 25% !important;
  }
  .pf-v6-u-w-33-on-sm {
    width: 33.3333333333% !important;
  }
  .pf-v6-u-w-50-on-sm {
    width: 50% !important;
  }
  .pf-v6-u-w-66-on-sm {
    width: 66.6666666667% !important;
  }
  .pf-v6-u-w-75-on-sm {
    width: 75% !important;
  }
  .pf-v6-u-w-100-on-sm {
    width: 100% !important;
  }
  .pf-v6-u-w-25vw-on-sm {
    width: 25vw !important;
  }
  .pf-v6-u-w-33vw-on-sm {
    width: 33.3333333333vw !important;
  }
  .pf-v6-u-w-50vw-on-sm {
    width: 50vw !important;
  }
  .pf-v6-u-w-66vw-on-sm {
    width: 66.6666666667vw !important;
  }
  .pf-v6-u-w-75vw-on-sm {
    width: 75vw !important;
  }
  .pf-v6-u-w-100vw-on-sm {
    width: 100vw !important;
  }
}
@media screen and (min-width: 48rem) {
  .pf-v6-u-w-auto-on-md {
    width: auto !important;
  }
  .pf-v6-u-w-initial-on-md {
    width: initial !important;
  }
  .pf-v6-u-w-inherit-on-md {
    width: inherit !important;
  }
  .pf-v6-u-w-0-on-md {
    width: 0% !important;
  }
  .pf-v6-u-w-25-on-md {
    width: 25% !important;
  }
  .pf-v6-u-w-33-on-md {
    width: 33.3333333333% !important;
  }
  .pf-v6-u-w-50-on-md {
    width: 50% !important;
  }
  .pf-v6-u-w-66-on-md {
    width: 66.6666666667% !important;
  }
  .pf-v6-u-w-75-on-md {
    width: 75% !important;
  }
  .pf-v6-u-w-100-on-md {
    width: 100% !important;
  }
  .pf-v6-u-w-25vw-on-md {
    width: 25vw !important;
  }
  .pf-v6-u-w-33vw-on-md {
    width: 33.3333333333vw !important;
  }
  .pf-v6-u-w-50vw-on-md {
    width: 50vw !important;
  }
  .pf-v6-u-w-66vw-on-md {
    width: 66.6666666667vw !important;
  }
  .pf-v6-u-w-75vw-on-md {
    width: 75vw !important;
  }
  .pf-v6-u-w-100vw-on-md {
    width: 100vw !important;
  }
}
@media screen and (min-width: 62rem) {
  .pf-v6-u-w-auto-on-lg {
    width: auto !important;
  }
  .pf-v6-u-w-initial-on-lg {
    width: initial !important;
  }
  .pf-v6-u-w-inherit-on-lg {
    width: inherit !important;
  }
  .pf-v6-u-w-0-on-lg {
    width: 0% !important;
  }
  .pf-v6-u-w-25-on-lg {
    width: 25% !important;
  }
  .pf-v6-u-w-33-on-lg {
    width: 33.3333333333% !important;
  }
  .pf-v6-u-w-50-on-lg {
    width: 50% !important;
  }
  .pf-v6-u-w-66-on-lg {
    width: 66.6666666667% !important;
  }
  .pf-v6-u-w-75-on-lg {
    width: 75% !important;
  }
  .pf-v6-u-w-100-on-lg {
    width: 100% !important;
  }
  .pf-v6-u-w-25vw-on-lg {
    width: 25vw !important;
  }
  .pf-v6-u-w-33vw-on-lg {
    width: 33.3333333333vw !important;
  }
  .pf-v6-u-w-50vw-on-lg {
    width: 50vw !important;
  }
  .pf-v6-u-w-66vw-on-lg {
    width: 66.6666666667vw !important;
  }
  .pf-v6-u-w-75vw-on-lg {
    width: 75vw !important;
  }
  .pf-v6-u-w-100vw-on-lg {
    width: 100vw !important;
  }
}
@media screen and (min-width: 75rem) {
  .pf-v6-u-w-auto-on-xl {
    width: auto !important;
  }
  .pf-v6-u-w-initial-on-xl {
    width: initial !important;
  }
  .pf-v6-u-w-inherit-on-xl {
    width: inherit !important;
  }
  .pf-v6-u-w-0-on-xl {
    width: 0% !important;
  }
  .pf-v6-u-w-25-on-xl {
    width: 25% !important;
  }
  .pf-v6-u-w-33-on-xl {
    width: 33.3333333333% !important;
  }
  .pf-v6-u-w-50-on-xl {
    width: 50% !important;
  }
  .pf-v6-u-w-66-on-xl {
    width: 66.6666666667% !important;
  }
  .pf-v6-u-w-75-on-xl {
    width: 75% !important;
  }
  .pf-v6-u-w-100-on-xl {
    width: 100% !important;
  }
  .pf-v6-u-w-25vw-on-xl {
    width: 25vw !important;
  }
  .pf-v6-u-w-33vw-on-xl {
    width: 33.3333333333vw !important;
  }
  .pf-v6-u-w-50vw-on-xl {
    width: 50vw !important;
  }
  .pf-v6-u-w-66vw-on-xl {
    width: 66.6666666667vw !important;
  }
  .pf-v6-u-w-75vw-on-xl {
    width: 75vw !important;
  }
  .pf-v6-u-w-100vw-on-xl {
    width: 100vw !important;
  }
}
@media screen and (min-width: 90.625rem) {
  .pf-v6-u-w-auto-on-2xl {
    width: auto !important;
  }
  .pf-v6-u-w-initial-on-2xl {
    width: initial !important;
  }
  .pf-v6-u-w-inherit-on-2xl {
    width: inherit !important;
  }
  .pf-v6-u-w-0-on-2xl {
    width: 0% !important;
  }
  .pf-v6-u-w-25-on-2xl {
    width: 25% !important;
  }
  .pf-v6-u-w-33-on-2xl {
    width: 33.3333333333% !important;
  }
  .pf-v6-u-w-50-on-2xl {
    width: 50% !important;
  }
  .pf-v6-u-w-66-on-2xl {
    width: 66.6666666667% !important;
  }
  .pf-v6-u-w-75-on-2xl {
    width: 75% !important;
  }
  .pf-v6-u-w-100-on-2xl {
    width: 100% !important;
  }
  .pf-v6-u-w-25vw-on-2xl {
    width: 25vw !important;
  }
  .pf-v6-u-w-33vw-on-2xl {
    width: 33.3333333333vw !important;
  }
  .pf-v6-u-w-50vw-on-2xl {
    width: 50vw !important;
  }
  .pf-v6-u-w-66vw-on-2xl {
    width: 66.6666666667vw !important;
  }
  .pf-v6-u-w-75vw-on-2xl {
    width: 75vw !important;
  }
  .pf-v6-u-w-100vw-on-2xl {
    width: 100vw !important;
  }
}
.pf-v6-u-h-auto {
  height: auto !important;
}

.pf-v6-u-h-initial {
  height: initial !important;
}

.pf-v6-u-h-inherit {
  height: inherit !important;
}

.pf-v6-u-h-0 {
  height: 0% !important;
}

.pf-v6-u-h-25 {
  height: 25% !important;
}

.pf-v6-u-h-33 {
  height: 33.3333333333% !important;
}

.pf-v6-u-h-50 {
  height: 50% !important;
}

.pf-v6-u-h-66 {
  height: 66.6666666667% !important;
}

.pf-v6-u-h-75 {
  height: 75% !important;
}

.pf-v6-u-h-100 {
  height: 100% !important;
}

.pf-v6-u-h-25vh {
  height: 25vh !important;
}

.pf-v6-u-h-33vh {
  height: 33.3333333333vh !important;
}

.pf-v6-u-h-50vh {
  height: 50vh !important;
}

.pf-v6-u-h-66vh {
  height: 66.6666666667vh !important;
}

.pf-v6-u-h-75vh {
  height: 75vh !important;
}

.pf-v6-u-h-100vh {
  height: 100vh !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-h-auto-on-sm {
    height: auto !important;
  }
  .pf-v6-u-h-initial-on-sm {
    height: initial !important;
  }
  .pf-v6-u-h-inherit-on-sm {
    height: inherit !important;
  }
  .pf-v6-u-h-0-on-sm {
    height: 0% !important;
  }
  .pf-v6-u-h-25-on-sm {
    height: 25% !important;
  }
  .pf-v6-u-h-33-on-sm {
    height: 33.3333333333% !important;
  }
  .pf-v6-u-h-50-on-sm {
    height: 50% !important;
  }
  .pf-v6-u-h-66-on-sm {
    height: 66.6666666667% !important;
  }
  .pf-v6-u-h-75-on-sm {
    height: 75% !important;
  }
  .pf-v6-u-h-100-on-sm {
    height: 100% !important;
  }
  .pf-v6-u-h-25vh-on-sm {
    height: 25vh !important;
  }
  .pf-v6-u-h-33vh-on-sm {
    height: 33.3333333333vh !important;
  }
  .pf-v6-u-h-50vh-on-sm {
    height: 50vh !important;
  }
  .pf-v6-u-h-66vh-on-sm {
    height: 66.6666666667vh !important;
  }
  .pf-v6-u-h-75vh-on-sm {
    height: 75vh !important;
  }
  .pf-v6-u-h-100vh-on-sm {
    height: 100vh !important;
  }
}
@media screen and (min-width: 48rem) {
  .pf-v6-u-h-auto-on-md {
    height: auto !important;
  }
  .pf-v6-u-h-initial-on-md {
    height: initial !important;
  }
  .pf-v6-u-h-inherit-on-md {
    height: inherit !important;
  }
  .pf-v6-u-h-0-on-md {
    height: 0% !important;
  }
  .pf-v6-u-h-25-on-md {
    height: 25% !important;
  }
  .pf-v6-u-h-33-on-md {
    height: 33.3333333333% !important;
  }
  .pf-v6-u-h-50-on-md {
    height: 50% !important;
  }
  .pf-v6-u-h-66-on-md {
    height: 66.6666666667% !important;
  }
  .pf-v6-u-h-75-on-md {
    height: 75% !important;
  }
  .pf-v6-u-h-100-on-md {
    height: 100% !important;
  }
  .pf-v6-u-h-25vh-on-md {
    height: 25vh !important;
  }
  .pf-v6-u-h-33vh-on-md {
    height: 33.3333333333vh !important;
  }
  .pf-v6-u-h-50vh-on-md {
    height: 50vh !important;
  }
  .pf-v6-u-h-66vh-on-md {
    height: 66.6666666667vh !important;
  }
  .pf-v6-u-h-75vh-on-md {
    height: 75vh !important;
  }
  .pf-v6-u-h-100vh-on-md {
    height: 100vh !important;
  }
}
@media screen and (min-width: 62rem) {
  .pf-v6-u-h-auto-on-lg {
    height: auto !important;
  }
  .pf-v6-u-h-initial-on-lg {
    height: initial !important;
  }
  .pf-v6-u-h-inherit-on-lg {
    height: inherit !important;
  }
  .pf-v6-u-h-0-on-lg {
    height: 0% !important;
  }
  .pf-v6-u-h-25-on-lg {
    height: 25% !important;
  }
  .pf-v6-u-h-33-on-lg {
    height: 33.3333333333% !important;
  }
  .pf-v6-u-h-50-on-lg {
    height: 50% !important;
  }
  .pf-v6-u-h-66-on-lg {
    height: 66.6666666667% !important;
  }
  .pf-v6-u-h-75-on-lg {
    height: 75% !important;
  }
  .pf-v6-u-h-100-on-lg {
    height: 100% !important;
  }
  .pf-v6-u-h-25vh-on-lg {
    height: 25vh !important;
  }
  .pf-v6-u-h-33vh-on-lg {
    height: 33.3333333333vh !important;
  }
  .pf-v6-u-h-50vh-on-lg {
    height: 50vh !important;
  }
  .pf-v6-u-h-66vh-on-lg {
    height: 66.6666666667vh !important;
  }
  .pf-v6-u-h-75vh-on-lg {
    height: 75vh !important;
  }
  .pf-v6-u-h-100vh-on-lg {
    height: 100vh !important;
  }
}
@media screen and (min-width: 75rem) {
  .pf-v6-u-h-auto-on-xl {
    height: auto !important;
  }
  .pf-v6-u-h-initial-on-xl {
    height: initial !important;
  }
  .pf-v6-u-h-inherit-on-xl {
    height: inherit !important;
  }
  .pf-v6-u-h-0-on-xl {
    height: 0% !important;
  }
  .pf-v6-u-h-25-on-xl {
    height: 25% !important;
  }
  .pf-v6-u-h-33-on-xl {
    height: 33.3333333333% !important;
  }
  .pf-v6-u-h-50-on-xl {
    height: 50% !important;
  }
  .pf-v6-u-h-66-on-xl {
    height: 66.6666666667% !important;
  }
  .pf-v6-u-h-75-on-xl {
    height: 75% !important;
  }
  .pf-v6-u-h-100-on-xl {
    height: 100% !important;
  }
  .pf-v6-u-h-25vh-on-xl {
    height: 25vh !important;
  }
  .pf-v6-u-h-33vh-on-xl {
    height: 33.3333333333vh !important;
  }
  .pf-v6-u-h-50vh-on-xl {
    height: 50vh !important;
  }
  .pf-v6-u-h-66vh-on-xl {
    height: 66.6666666667vh !important;
  }
  .pf-v6-u-h-75vh-on-xl {
    height: 75vh !important;
  }
  .pf-v6-u-h-100vh-on-xl {
    height: 100vh !important;
  }
}
@media screen and (min-width: 90.625rem) {
  .pf-v6-u-h-auto-on-2xl {
    height: auto !important;
  }
  .pf-v6-u-h-initial-on-2xl {
    height: initial !important;
  }
  .pf-v6-u-h-inherit-on-2xl {
    height: inherit !important;
  }
  .pf-v6-u-h-0-on-2xl {
    height: 0% !important;
  }
  .pf-v6-u-h-25-on-2xl {
    height: 25% !important;
  }
  .pf-v6-u-h-33-on-2xl {
    height: 33.3333333333% !important;
  }
  .pf-v6-u-h-50-on-2xl {
    height: 50% !important;
  }
  .pf-v6-u-h-66-on-2xl {
    height: 66.6666666667% !important;
  }
  .pf-v6-u-h-75-on-2xl {
    height: 75% !important;
  }
  .pf-v6-u-h-100-on-2xl {
    height: 100% !important;
  }
  .pf-v6-u-h-25vh-on-2xl {
    height: 25vh !important;
  }
  .pf-v6-u-h-33vh-on-2xl {
    height: 33.3333333333vh !important;
  }
  .pf-v6-u-h-50vh-on-2xl {
    height: 50vh !important;
  }
  .pf-v6-u-h-66vh-on-2xl {
    height: 66.6666666667vh !important;
  }
  .pf-v6-u-h-75vh-on-2xl {
    height: 75vh !important;
  }
  .pf-v6-u-h-100vh-on-2xl {
    height: 100vh !important;
  }
}
.pf-v6-u-min-width {
  --pf-v6-u-min-width--MinWidth: 0;
  min-width: var(--pf-v6-u-min-width--MinWidth) !important;
}
@media (min-width: 36rem) {
  .pf-v6-u-min-width {
    min-width: var(--pf-v6-u-min-width--MinWidth-on-sm, var(--pf-v6-u-min-width--MinWidth)) !important;
  }
}
@media (min-width: 48rem) {
  .pf-v6-u-min-width {
    min-width: var(--pf-v6-u-min-width--MinWidth-on-md, var(--pf-v6-u-min-width--MinWidth-on-sm, var(--pf-v6-u-min-width--MinWidth))) !important;
  }
}
@media (min-width: 62rem) {
  .pf-v6-u-min-width {
    min-width: var(--pf-v6-u-min-width--MinWidth-on-lg, var(--pf-v6-u-min-width--MinWidth-on-md, var(--pf-v6-u-min-width--MinWidth-on-sm, var(--pf-v6-u-min-width--MinWidth)))) !important;
  }
}
@media (min-width: 75rem) {
  .pf-v6-u-min-width {
    min-width: var(--pf-v6-u-min-width--MinWidth-on-xl, var(--pf-v6-u-min-width--MinWidth-on-lg, var(--pf-v6-u-min-width--MinWidth-on-md, var(--pf-v6-u-min-width--MinWidth-on-sm, var(--pf-v6-u-min-width--MinWidth))))) !important;
  }
}
@media (min-width: 90.625rem) {
  .pf-v6-u-min-width {
    min-width: var(--pf-v6-u-min-width--MinWidth-on-2xl, var(--pf-v6-u-min-width--MinWidth-on-xl, var(--pf-v6-u-min-width--MinWidth-on-lg, var(--pf-v6-u-min-width--MinWidth-on-md, var(--pf-v6-u-min-width--MinWidth-on-sm, var(--pf-v6-u-min-width--MinWidth)))))) !important;
  }
}

.pf-v6-u-max-width {
  --pf-v6-u-max-width--MaxWidth: auto;
  max-width: var(--pf-v6-u-max-width--MaxWidth) !important;
}
@media (min-width: 36rem) {
  .pf-v6-u-max-width {
    max-width: var(--pf-v6-u-max-width--MaxWidth-on-sm, var(--pf-v6-u-max-width--MaxWidth)) !important;
  }
}
@media (min-width: 48rem) {
  .pf-v6-u-max-width {
    max-width: var(--pf-v6-u-max-width--MaxWidth-on-md, var(--pf-v6-u-max-width--MaxWidth-on-sm, var(--pf-v6-u-max-width--MaxWidth))) !important;
  }
}
@media (min-width: 62rem) {
  .pf-v6-u-max-width {
    max-width: var(--pf-v6-u-max-width--MaxWidth-on-lg, var(--pf-v6-u-max-width--MaxWidth-on-md, var(--pf-v6-u-max-width--MaxWidth-on-sm, var(--pf-v6-u-max-width--MaxWidth)))) !important;
  }
}
@media (min-width: 75rem) {
  .pf-v6-u-max-width {
    max-width: var(--pf-v6-u-max-width--MaxWidth-on-xl, var(--pf-v6-u-max-width--MaxWidth-on-lg, var(--pf-v6-u-max-width--MaxWidth-on-md, var(--pf-v6-u-max-width--MaxWidth-on-sm, var(--pf-v6-u-max-width--MaxWidth))))) !important;
  }
}
@media (min-width: 90.625rem) {
  .pf-v6-u-max-width {
    max-width: var(--pf-v6-u-max-width--MaxWidth-on-2xl, var(--pf-v6-u-max-width--MaxWidth-on-xl, var(--pf-v6-u-max-width--MaxWidth-on-lg, var(--pf-v6-u-max-width--MaxWidth-on-md, var(--pf-v6-u-max-width--MaxWidth-on-sm, var(--pf-v6-u-max-width--MaxWidth)))))) !important;
  }
}

.pf-v6-u-min-height {
  --pf-v6-u-min-height--MinHeight: 0;
  min-height: var(--pf-v6-u-min-height--MinHeight) !important;
}
@media (min-width: 36rem) {
  .pf-v6-u-min-height {
    min-height: var(--pf-v6-u-min-height--MinHeight-on-sm, var(--pf-v6-u-min-height--MinHeight)) !important;
  }
}
@media (min-width: 48rem) {
  .pf-v6-u-min-height {
    min-height: var(--pf-v6-u-min-height--MinHeight-on-md, var(--pf-v6-u-min-height--MinHeight-on-sm, var(--pf-v6-u-min-height--MinHeight))) !important;
  }
}
@media (min-width: 62rem) {
  .pf-v6-u-min-height {
    min-height: var(--pf-v6-u-min-height--MinHeight-on-lg, var(--pf-v6-u-min-height--MinHeight-on-md, var(--pf-v6-u-min-height--MinHeight-on-sm, var(--pf-v6-u-min-height--MinHeight)))) !important;
  }
}
@media (min-width: 75rem) {
  .pf-v6-u-min-height {
    min-height: var(--pf-v6-u-min-height--MinHeight-on-xl, var(--pf-v6-u-min-height--MinHeight-on-lg, var(--pf-v6-u-min-height--MinHeight-on-md, var(--pf-v6-u-min-height--MinHeight-on-sm, var(--pf-v6-u-min-height--MinHeight))))) !important;
  }
}
@media (min-width: 90.625rem) {
  .pf-v6-u-min-height {
    min-height: var(--pf-v6-u-min-height--MinHeight-on-2xl, var(--pf-v6-u-min-height--MinHeight-on-xl, var(--pf-v6-u-min-height--MinHeight-on-lg, var(--pf-v6-u-min-height--MinHeight-on-md, var(--pf-v6-u-min-height--MinHeight-on-sm, var(--pf-v6-u-min-height--MinHeight)))))) !important;
  }
}

.pf-v6-u-max-height {
  --pf-v6-u-max-height--MaxHeight: auto;
  max-height: var(--pf-v6-u-max-height--MaxHeight) !important;
}
@media (min-width: 36rem) {
  .pf-v6-u-max-height {
    max-height: var(--pf-v6-u-max-height--MaxHeight-on-sm, var(--pf-v6-u-max-height--MaxHeight)) !important;
  }
}
@media (min-width: 48rem) {
  .pf-v6-u-max-height {
    max-height: var(--pf-v6-u-max-height--MaxHeight-on-md, var(--pf-v6-u-max-height--MaxHeight-on-sm, var(--pf-v6-u-max-height--MaxHeight))) !important;
  }
}
@media (min-width: 62rem) {
  .pf-v6-u-max-height {
    max-height: var(--pf-v6-u-max-height--MaxHeight-on-lg, var(--pf-v6-u-max-height--MaxHeight-on-md, var(--pf-v6-u-max-height--MaxHeight-on-sm, var(--pf-v6-u-max-height--MaxHeight)))) !important;
  }
}
@media (min-width: 75rem) {
  .pf-v6-u-max-height {
    max-height: var(--pf-v6-u-max-height--MaxHeight-on-xl, var(--pf-v6-u-max-height--MaxHeight-on-lg, var(--pf-v6-u-max-height--MaxHeight-on-md, var(--pf-v6-u-max-height--MaxHeight-on-sm, var(--pf-v6-u-max-height--MaxHeight))))) !important;
  }
}
@media (min-width: 90.625rem) {
  .pf-v6-u-max-height {
    max-height: var(--pf-v6-u-max-height--MaxHeight-on-2xl, var(--pf-v6-u-max-height--MaxHeight-on-xl, var(--pf-v6-u-max-height--MaxHeight-on-lg, var(--pf-v6-u-max-height--MaxHeight-on-md, var(--pf-v6-u-max-height--MaxHeight-on-sm, var(--pf-v6-u-max-height--MaxHeight)))))) !important;
  }
}

.pf-v6-u-m-auto {
  margin: auto !important;
}

.pf-v6-u-m-0 {
  margin: 0 !important;
}

.pf-v6-u-m-xs {
  margin: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-m-sm {
  margin: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-m-md {
  margin: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-m-lg {
  margin: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-m-xl {
  margin: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-m-2xl {
  margin: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-m-3xl {
  margin: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-m-4xl {
  margin: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-mt-auto {
  margin-block-start: auto !important;
}

.pf-v6-u-mt-0 {
  margin-block-start: 0 !important;
}

.pf-v6-u-mt-xs {
  margin-block-start: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-mt-sm {
  margin-block-start: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-mt-md {
  margin-block-start: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-mt-lg {
  margin-block-start: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-mt-xl {
  margin-block-start: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-mt-2xl {
  margin-block-start: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-mt-3xl {
  margin-block-start: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-mt-4xl {
  margin-block-start: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-mr-auto {
  margin-inline-end: auto !important;
}

.pf-v6-u-mr-0 {
  margin-inline-end: 0 !important;
}

.pf-v6-u-mr-xs {
  margin-inline-end: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-mr-sm {
  margin-inline-end: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-mr-md {
  margin-inline-end: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-mr-lg {
  margin-inline-end: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-mr-xl {
  margin-inline-end: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-mr-2xl {
  margin-inline-end: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-mr-3xl {
  margin-inline-end: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-mr-4xl {
  margin-inline-end: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-mb-auto {
  margin-block-end: auto !important;
}

.pf-v6-u-mb-0 {
  margin-block-end: 0 !important;
}

.pf-v6-u-mb-xs {
  margin-block-end: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-mb-sm {
  margin-block-end: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-mb-md {
  margin-block-end: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-mb-lg {
  margin-block-end: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-mb-xl {
  margin-block-end: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-mb-2xl {
  margin-block-end: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-mb-3xl {
  margin-block-end: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-mb-4xl {
  margin-block-end: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-ml-auto {
  margin-inline-start: auto !important;
}

.pf-v6-u-ml-0 {
  margin-inline-start: 0 !important;
}

.pf-v6-u-ml-xs {
  margin-inline-start: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-ml-sm {
  margin-inline-start: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-ml-md {
  margin-inline-start: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-ml-lg {
  margin-inline-start: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-ml-xl {
  margin-inline-start: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-ml-2xl {
  margin-inline-start: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-ml-3xl {
  margin-inline-start: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-ml-4xl {
  margin-inline-start: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-mx-auto {
  margin-inline: auto !important;
}

.pf-v6-u-mx-0 {
  margin-inline: 0 !important;
}

.pf-v6-u-mx-xs {
  margin-inline: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-mx-sm {
  margin-inline: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-mx-md {
  margin-inline: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-mx-lg {
  margin-inline: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-mx-xl {
  margin-inline: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-mx-2xl {
  margin-inline: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-mx-3xl {
  margin-inline: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-mx-4xl {
  margin-inline: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-my-auto {
  margin-block: auto !important;
}

.pf-v6-u-my-0 {
  margin-block: 0 !important;
}

.pf-v6-u-my-xs {
  margin-block: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-my-sm {
  margin-block: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-my-md {
  margin-block: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-my-lg {
  margin-block: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-my-xl {
  margin-block: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-my-2xl {
  margin-block: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-my-3xl {
  margin-block: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-my-4xl {
  margin-block: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-p-auto {
  padding: auto !important;
}

.pf-v6-u-p-0 {
  padding: 0 !important;
}

.pf-v6-u-p-xs {
  padding: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-p-sm {
  padding: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-p-md {
  padding: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-p-lg {
  padding: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-p-xl {
  padding: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-p-2xl {
  padding: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-p-3xl {
  padding: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-p-4xl {
  padding: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-pt-auto {
  padding-block-start: auto !important;
}

.pf-v6-u-pt-0 {
  padding-block-start: 0 !important;
}

.pf-v6-u-pt-xs {
  padding-block-start: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-pt-sm {
  padding-block-start: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-pt-md {
  padding-block-start: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-pt-lg {
  padding-block-start: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-pt-xl {
  padding-block-start: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-pt-2xl {
  padding-block-start: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-pt-3xl {
  padding-block-start: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-pt-4xl {
  padding-block-start: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-pr-auto {
  padding-inline-end: auto !important;
}

.pf-v6-u-pr-0 {
  padding-inline-end: 0 !important;
}

.pf-v6-u-pr-xs {
  padding-inline-end: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-pr-sm {
  padding-inline-end: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-pr-md {
  padding-inline-end: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-pr-lg {
  padding-inline-end: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-pr-xl {
  padding-inline-end: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-pr-2xl {
  padding-inline-end: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-pr-3xl {
  padding-inline-end: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-pr-4xl {
  padding-inline-end: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-pb-auto {
  padding-block-end: auto !important;
}

.pf-v6-u-pb-0 {
  padding-block-end: 0 !important;
}

.pf-v6-u-pb-xs {
  padding-block-end: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-pb-sm {
  padding-block-end: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-pb-md {
  padding-block-end: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-pb-lg {
  padding-block-end: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-pb-xl {
  padding-block-end: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-pb-2xl {
  padding-block-end: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-pb-3xl {
  padding-block-end: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-pb-4xl {
  padding-block-end: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-pl-auto {
  padding-inline-start: auto !important;
}

.pf-v6-u-pl-0 {
  padding-inline-start: 0 !important;
}

.pf-v6-u-pl-xs {
  padding-inline-start: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-pl-sm {
  padding-inline-start: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-pl-md {
  padding-inline-start: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-pl-lg {
  padding-inline-start: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-pl-xl {
  padding-inline-start: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-pl-2xl {
  padding-inline-start: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-pl-3xl {
  padding-inline-start: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-pl-4xl {
  padding-inline-start: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-px-auto {
  padding-inline: auto !important;
}

.pf-v6-u-px-0 {
  padding-inline: 0 !important;
}

.pf-v6-u-px-xs {
  padding-inline: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-px-sm {
  padding-inline: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-px-md {
  padding-inline: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-px-lg {
  padding-inline: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-px-xl {
  padding-inline: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-px-2xl {
  padding-inline: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-px-3xl {
  padding-inline: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-px-4xl {
  padding-inline: var(--pf-t--global--spacer--4xl) !important;
}

.pf-v6-u-py-auto {
  padding-block: auto !important;
}

.pf-v6-u-py-0 {
  padding-block: 0 !important;
}

.pf-v6-u-py-xs {
  padding-block: var(--pf-t--global--spacer--xs) !important;
}

.pf-v6-u-py-sm {
  padding-block: var(--pf-t--global--spacer--sm) !important;
}

.pf-v6-u-py-md {
  padding-block: var(--pf-t--global--spacer--md) !important;
}

.pf-v6-u-py-lg {
  padding-block: var(--pf-t--global--spacer--lg) !important;
}

.pf-v6-u-py-xl {
  padding-block: var(--pf-t--global--spacer--xl) !important;
}

.pf-v6-u-py-2xl {
  padding-block: var(--pf-t--global--spacer--2xl) !important;
}

.pf-v6-u-py-3xl {
  padding-block: var(--pf-t--global--spacer--3xl) !important;
}

.pf-v6-u-py-4xl {
  padding-block: var(--pf-t--global--spacer--4xl) !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-m-auto-on-sm {
    margin: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-m-0-on-sm {
    margin: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-m-xs-on-sm {
    margin: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-m-sm-on-sm {
    margin: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-m-md-on-sm {
    margin: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-m-lg-on-sm {
    margin: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-m-xl-on-sm {
    margin: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-m-2xl-on-sm {
    margin: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-m-3xl-on-sm {
    margin: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-m-4xl-on-sm {
    margin: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mt-auto-on-sm {
    margin-block-start: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mt-0-on-sm {
    margin-block-start: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mt-xs-on-sm {
    margin-block-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mt-sm-on-sm {
    margin-block-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mt-md-on-sm {
    margin-block-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mt-lg-on-sm {
    margin-block-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mt-xl-on-sm {
    margin-block-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mt-2xl-on-sm {
    margin-block-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mt-3xl-on-sm {
    margin-block-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mt-4xl-on-sm {
    margin-block-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mr-auto-on-sm {
    margin-inline-end: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mr-0-on-sm {
    margin-inline-end: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mr-xs-on-sm {
    margin-inline-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mr-sm-on-sm {
    margin-inline-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mr-md-on-sm {
    margin-inline-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mr-lg-on-sm {
    margin-inline-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mr-xl-on-sm {
    margin-inline-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mr-2xl-on-sm {
    margin-inline-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mr-3xl-on-sm {
    margin-inline-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mr-4xl-on-sm {
    margin-inline-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mb-auto-on-sm {
    margin-block-end: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mb-0-on-sm {
    margin-block-end: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mb-xs-on-sm {
    margin-block-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mb-sm-on-sm {
    margin-block-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mb-md-on-sm {
    margin-block-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mb-lg-on-sm {
    margin-block-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mb-xl-on-sm {
    margin-block-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mb-2xl-on-sm {
    margin-block-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mb-3xl-on-sm {
    margin-block-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mb-4xl-on-sm {
    margin-block-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-ml-auto-on-sm {
    margin-inline-start: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-ml-0-on-sm {
    margin-inline-start: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-ml-xs-on-sm {
    margin-inline-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-ml-sm-on-sm {
    margin-inline-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-ml-md-on-sm {
    margin-inline-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-ml-lg-on-sm {
    margin-inline-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-ml-xl-on-sm {
    margin-inline-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-ml-2xl-on-sm {
    margin-inline-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-ml-3xl-on-sm {
    margin-inline-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-ml-4xl-on-sm {
    margin-inline-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mx-auto-on-sm {
    margin-inline: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mx-0-on-sm {
    margin-inline: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mx-xs-on-sm {
    margin-inline: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mx-sm-on-sm {
    margin-inline: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mx-md-on-sm {
    margin-inline: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mx-lg-on-sm {
    margin-inline: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mx-xl-on-sm {
    margin-inline: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mx-2xl-on-sm {
    margin-inline: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mx-3xl-on-sm {
    margin-inline: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-mx-4xl-on-sm {
    margin-inline: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-my-auto-on-sm {
    margin-block: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-my-0-on-sm {
    margin-block: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-my-xs-on-sm {
    margin-block: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-my-sm-on-sm {
    margin-block: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-my-md-on-sm {
    margin-block: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-my-lg-on-sm {
    margin-block: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-my-xl-on-sm {
    margin-block: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-my-2xl-on-sm {
    margin-block: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-my-3xl-on-sm {
    margin-block: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-my-4xl-on-sm {
    margin-block: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-p-auto-on-sm {
    padding: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-p-0-on-sm {
    padding: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-p-xs-on-sm {
    padding: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-p-sm-on-sm {
    padding: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-p-md-on-sm {
    padding: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-p-lg-on-sm {
    padding: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-p-xl-on-sm {
    padding: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-p-2xl-on-sm {
    padding: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-p-3xl-on-sm {
    padding: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-p-4xl-on-sm {
    padding: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pt-auto-on-sm {
    padding-block-start: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pt-0-on-sm {
    padding-block-start: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pt-xs-on-sm {
    padding-block-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pt-sm-on-sm {
    padding-block-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pt-md-on-sm {
    padding-block-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pt-lg-on-sm {
    padding-block-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pt-xl-on-sm {
    padding-block-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pt-2xl-on-sm {
    padding-block-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pt-3xl-on-sm {
    padding-block-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pt-4xl-on-sm {
    padding-block-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pr-auto-on-sm {
    padding-inline-end: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pr-0-on-sm {
    padding-inline-end: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pr-xs-on-sm {
    padding-inline-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pr-sm-on-sm {
    padding-inline-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pr-md-on-sm {
    padding-inline-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pr-lg-on-sm {
    padding-inline-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pr-xl-on-sm {
    padding-inline-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pr-2xl-on-sm {
    padding-inline-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pr-3xl-on-sm {
    padding-inline-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pr-4xl-on-sm {
    padding-inline-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pb-auto-on-sm {
    padding-block-end: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pb-0-on-sm {
    padding-block-end: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pb-xs-on-sm {
    padding-block-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pb-sm-on-sm {
    padding-block-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pb-md-on-sm {
    padding-block-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pb-lg-on-sm {
    padding-block-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pb-xl-on-sm {
    padding-block-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pb-2xl-on-sm {
    padding-block-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pb-3xl-on-sm {
    padding-block-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pb-4xl-on-sm {
    padding-block-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pl-auto-on-sm {
    padding-inline-start: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pl-0-on-sm {
    padding-inline-start: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pl-xs-on-sm {
    padding-inline-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pl-sm-on-sm {
    padding-inline-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pl-md-on-sm {
    padding-inline-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pl-lg-on-sm {
    padding-inline-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pl-xl-on-sm {
    padding-inline-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pl-2xl-on-sm {
    padding-inline-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pl-3xl-on-sm {
    padding-inline-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-pl-4xl-on-sm {
    padding-inline-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-px-auto-on-sm {
    padding-inline: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-px-0-on-sm {
    padding-inline: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-px-xs-on-sm {
    padding-inline: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-px-sm-on-sm {
    padding-inline: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-px-md-on-sm {
    padding-inline: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-px-lg-on-sm {
    padding-inline: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-px-xl-on-sm {
    padding-inline: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-px-2xl-on-sm {
    padding-inline: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-px-3xl-on-sm {
    padding-inline: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-px-4xl-on-sm {
    padding-inline: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-py-auto-on-sm {
    padding-block: auto !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-py-0-on-sm {
    padding-block: 0 !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-py-xs-on-sm {
    padding-block: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-py-sm-on-sm {
    padding-block: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-py-md-on-sm {
    padding-block: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-py-lg-on-sm {
    padding-block: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-py-xl-on-sm {
    padding-block: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-py-2xl-on-sm {
    padding-block: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-py-3xl-on-sm {
    padding-block: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-py-4xl-on-sm {
    padding-block: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-m-auto-on-md {
    margin: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-m-0-on-md {
    margin: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-m-xs-on-md {
    margin: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-m-sm-on-md {
    margin: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-m-md-on-md {
    margin: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-m-lg-on-md {
    margin: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-m-xl-on-md {
    margin: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-m-2xl-on-md {
    margin: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-m-3xl-on-md {
    margin: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-m-4xl-on-md {
    margin: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mt-auto-on-md {
    margin-block-start: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mt-0-on-md {
    margin-block-start: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mt-xs-on-md {
    margin-block-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mt-sm-on-md {
    margin-block-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mt-md-on-md {
    margin-block-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mt-lg-on-md {
    margin-block-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mt-xl-on-md {
    margin-block-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mt-2xl-on-md {
    margin-block-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mt-3xl-on-md {
    margin-block-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mt-4xl-on-md {
    margin-block-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mr-auto-on-md {
    margin-inline-end: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mr-0-on-md {
    margin-inline-end: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mr-xs-on-md {
    margin-inline-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mr-sm-on-md {
    margin-inline-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mr-md-on-md {
    margin-inline-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mr-lg-on-md {
    margin-inline-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mr-xl-on-md {
    margin-inline-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mr-2xl-on-md {
    margin-inline-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mr-3xl-on-md {
    margin-inline-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mr-4xl-on-md {
    margin-inline-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mb-auto-on-md {
    margin-block-end: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mb-0-on-md {
    margin-block-end: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mb-xs-on-md {
    margin-block-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mb-sm-on-md {
    margin-block-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mb-md-on-md {
    margin-block-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mb-lg-on-md {
    margin-block-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mb-xl-on-md {
    margin-block-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mb-2xl-on-md {
    margin-block-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mb-3xl-on-md {
    margin-block-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mb-4xl-on-md {
    margin-block-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-ml-auto-on-md {
    margin-inline-start: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-ml-0-on-md {
    margin-inline-start: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-ml-xs-on-md {
    margin-inline-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-ml-sm-on-md {
    margin-inline-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-ml-md-on-md {
    margin-inline-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-ml-lg-on-md {
    margin-inline-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-ml-xl-on-md {
    margin-inline-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-ml-2xl-on-md {
    margin-inline-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-ml-3xl-on-md {
    margin-inline-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-ml-4xl-on-md {
    margin-inline-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mx-auto-on-md {
    margin-inline: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mx-0-on-md {
    margin-inline: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mx-xs-on-md {
    margin-inline: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mx-sm-on-md {
    margin-inline: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mx-md-on-md {
    margin-inline: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mx-lg-on-md {
    margin-inline: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mx-xl-on-md {
    margin-inline: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mx-2xl-on-md {
    margin-inline: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mx-3xl-on-md {
    margin-inline: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-mx-4xl-on-md {
    margin-inline: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-my-auto-on-md {
    margin-block: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-my-0-on-md {
    margin-block: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-my-xs-on-md {
    margin-block: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-my-sm-on-md {
    margin-block: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-my-md-on-md {
    margin-block: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-my-lg-on-md {
    margin-block: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-my-xl-on-md {
    margin-block: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-my-2xl-on-md {
    margin-block: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-my-3xl-on-md {
    margin-block: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-my-4xl-on-md {
    margin-block: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-p-auto-on-md {
    padding: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-p-0-on-md {
    padding: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-p-xs-on-md {
    padding: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-p-sm-on-md {
    padding: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-p-md-on-md {
    padding: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-p-lg-on-md {
    padding: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-p-xl-on-md {
    padding: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-p-2xl-on-md {
    padding: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-p-3xl-on-md {
    padding: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-p-4xl-on-md {
    padding: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pt-auto-on-md {
    padding-block-start: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pt-0-on-md {
    padding-block-start: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pt-xs-on-md {
    padding-block-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pt-sm-on-md {
    padding-block-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pt-md-on-md {
    padding-block-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pt-lg-on-md {
    padding-block-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pt-xl-on-md {
    padding-block-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pt-2xl-on-md {
    padding-block-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pt-3xl-on-md {
    padding-block-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pt-4xl-on-md {
    padding-block-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pr-auto-on-md {
    padding-inline-end: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pr-0-on-md {
    padding-inline-end: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pr-xs-on-md {
    padding-inline-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pr-sm-on-md {
    padding-inline-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pr-md-on-md {
    padding-inline-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pr-lg-on-md {
    padding-inline-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pr-xl-on-md {
    padding-inline-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pr-2xl-on-md {
    padding-inline-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pr-3xl-on-md {
    padding-inline-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pr-4xl-on-md {
    padding-inline-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pb-auto-on-md {
    padding-block-end: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pb-0-on-md {
    padding-block-end: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pb-xs-on-md {
    padding-block-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pb-sm-on-md {
    padding-block-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pb-md-on-md {
    padding-block-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pb-lg-on-md {
    padding-block-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pb-xl-on-md {
    padding-block-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pb-2xl-on-md {
    padding-block-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pb-3xl-on-md {
    padding-block-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pb-4xl-on-md {
    padding-block-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pl-auto-on-md {
    padding-inline-start: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pl-0-on-md {
    padding-inline-start: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pl-xs-on-md {
    padding-inline-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pl-sm-on-md {
    padding-inline-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pl-md-on-md {
    padding-inline-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pl-lg-on-md {
    padding-inline-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pl-xl-on-md {
    padding-inline-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pl-2xl-on-md {
    padding-inline-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pl-3xl-on-md {
    padding-inline-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-pl-4xl-on-md {
    padding-inline-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-px-auto-on-md {
    padding-inline: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-px-0-on-md {
    padding-inline: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-px-xs-on-md {
    padding-inline: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-px-sm-on-md {
    padding-inline: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-px-md-on-md {
    padding-inline: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-px-lg-on-md {
    padding-inline: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-px-xl-on-md {
    padding-inline: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-px-2xl-on-md {
    padding-inline: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-px-3xl-on-md {
    padding-inline: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-px-4xl-on-md {
    padding-inline: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-py-auto-on-md {
    padding-block: auto !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-py-0-on-md {
    padding-block: 0 !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-py-xs-on-md {
    padding-block: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-py-sm-on-md {
    padding-block: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-py-md-on-md {
    padding-block: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-py-lg-on-md {
    padding-block: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-py-xl-on-md {
    padding-block: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-py-2xl-on-md {
    padding-block: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-py-3xl-on-md {
    padding-block: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 48rem) {
  .pf-v6-u-py-4xl-on-md {
    padding-block: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-m-auto-on-lg {
    margin: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-m-0-on-lg {
    margin: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-m-xs-on-lg {
    margin: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-m-sm-on-lg {
    margin: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-m-md-on-lg {
    margin: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-m-lg-on-lg {
    margin: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-m-xl-on-lg {
    margin: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-m-2xl-on-lg {
    margin: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-m-3xl-on-lg {
    margin: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-m-4xl-on-lg {
    margin: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mt-auto-on-lg {
    margin-block-start: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mt-0-on-lg {
    margin-block-start: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mt-xs-on-lg {
    margin-block-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mt-sm-on-lg {
    margin-block-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mt-md-on-lg {
    margin-block-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mt-lg-on-lg {
    margin-block-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mt-xl-on-lg {
    margin-block-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mt-2xl-on-lg {
    margin-block-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mt-3xl-on-lg {
    margin-block-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mt-4xl-on-lg {
    margin-block-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mr-auto-on-lg {
    margin-inline-end: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mr-0-on-lg {
    margin-inline-end: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mr-xs-on-lg {
    margin-inline-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mr-sm-on-lg {
    margin-inline-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mr-md-on-lg {
    margin-inline-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mr-lg-on-lg {
    margin-inline-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mr-xl-on-lg {
    margin-inline-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mr-2xl-on-lg {
    margin-inline-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mr-3xl-on-lg {
    margin-inline-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mr-4xl-on-lg {
    margin-inline-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mb-auto-on-lg {
    margin-block-end: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mb-0-on-lg {
    margin-block-end: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mb-xs-on-lg {
    margin-block-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mb-sm-on-lg {
    margin-block-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mb-md-on-lg {
    margin-block-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mb-lg-on-lg {
    margin-block-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mb-xl-on-lg {
    margin-block-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mb-2xl-on-lg {
    margin-block-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mb-3xl-on-lg {
    margin-block-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mb-4xl-on-lg {
    margin-block-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-ml-auto-on-lg {
    margin-inline-start: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-ml-0-on-lg {
    margin-inline-start: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-ml-xs-on-lg {
    margin-inline-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-ml-sm-on-lg {
    margin-inline-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-ml-md-on-lg {
    margin-inline-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-ml-lg-on-lg {
    margin-inline-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-ml-xl-on-lg {
    margin-inline-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-ml-2xl-on-lg {
    margin-inline-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-ml-3xl-on-lg {
    margin-inline-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-ml-4xl-on-lg {
    margin-inline-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mx-auto-on-lg {
    margin-inline: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mx-0-on-lg {
    margin-inline: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mx-xs-on-lg {
    margin-inline: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mx-sm-on-lg {
    margin-inline: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mx-md-on-lg {
    margin-inline: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mx-lg-on-lg {
    margin-inline: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mx-xl-on-lg {
    margin-inline: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mx-2xl-on-lg {
    margin-inline: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mx-3xl-on-lg {
    margin-inline: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-mx-4xl-on-lg {
    margin-inline: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-my-auto-on-lg {
    margin-block: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-my-0-on-lg {
    margin-block: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-my-xs-on-lg {
    margin-block: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-my-sm-on-lg {
    margin-block: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-my-md-on-lg {
    margin-block: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-my-lg-on-lg {
    margin-block: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-my-xl-on-lg {
    margin-block: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-my-2xl-on-lg {
    margin-block: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-my-3xl-on-lg {
    margin-block: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-my-4xl-on-lg {
    margin-block: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-p-auto-on-lg {
    padding: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-p-0-on-lg {
    padding: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-p-xs-on-lg {
    padding: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-p-sm-on-lg {
    padding: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-p-md-on-lg {
    padding: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-p-lg-on-lg {
    padding: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-p-xl-on-lg {
    padding: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-p-2xl-on-lg {
    padding: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-p-3xl-on-lg {
    padding: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-p-4xl-on-lg {
    padding: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pt-auto-on-lg {
    padding-block-start: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pt-0-on-lg {
    padding-block-start: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pt-xs-on-lg {
    padding-block-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pt-sm-on-lg {
    padding-block-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pt-md-on-lg {
    padding-block-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pt-lg-on-lg {
    padding-block-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pt-xl-on-lg {
    padding-block-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pt-2xl-on-lg {
    padding-block-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pt-3xl-on-lg {
    padding-block-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pt-4xl-on-lg {
    padding-block-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pr-auto-on-lg {
    padding-inline-end: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pr-0-on-lg {
    padding-inline-end: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pr-xs-on-lg {
    padding-inline-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pr-sm-on-lg {
    padding-inline-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pr-md-on-lg {
    padding-inline-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pr-lg-on-lg {
    padding-inline-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pr-xl-on-lg {
    padding-inline-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pr-2xl-on-lg {
    padding-inline-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pr-3xl-on-lg {
    padding-inline-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pr-4xl-on-lg {
    padding-inline-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pb-auto-on-lg {
    padding-block-end: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pb-0-on-lg {
    padding-block-end: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pb-xs-on-lg {
    padding-block-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pb-sm-on-lg {
    padding-block-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pb-md-on-lg {
    padding-block-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pb-lg-on-lg {
    padding-block-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pb-xl-on-lg {
    padding-block-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pb-2xl-on-lg {
    padding-block-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pb-3xl-on-lg {
    padding-block-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pb-4xl-on-lg {
    padding-block-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pl-auto-on-lg {
    padding-inline-start: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pl-0-on-lg {
    padding-inline-start: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pl-xs-on-lg {
    padding-inline-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pl-sm-on-lg {
    padding-inline-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pl-md-on-lg {
    padding-inline-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pl-lg-on-lg {
    padding-inline-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pl-xl-on-lg {
    padding-inline-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pl-2xl-on-lg {
    padding-inline-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pl-3xl-on-lg {
    padding-inline-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-pl-4xl-on-lg {
    padding-inline-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-px-auto-on-lg {
    padding-inline: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-px-0-on-lg {
    padding-inline: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-px-xs-on-lg {
    padding-inline: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-px-sm-on-lg {
    padding-inline: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-px-md-on-lg {
    padding-inline: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-px-lg-on-lg {
    padding-inline: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-px-xl-on-lg {
    padding-inline: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-px-2xl-on-lg {
    padding-inline: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-px-3xl-on-lg {
    padding-inline: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-px-4xl-on-lg {
    padding-inline: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-py-auto-on-lg {
    padding-block: auto !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-py-0-on-lg {
    padding-block: 0 !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-py-xs-on-lg {
    padding-block: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-py-sm-on-lg {
    padding-block: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-py-md-on-lg {
    padding-block: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-py-lg-on-lg {
    padding-block: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-py-xl-on-lg {
    padding-block: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-py-2xl-on-lg {
    padding-block: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-py-3xl-on-lg {
    padding-block: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 62rem) {
  .pf-v6-u-py-4xl-on-lg {
    padding-block: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-m-auto-on-xl {
    margin: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-m-0-on-xl {
    margin: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-m-xs-on-xl {
    margin: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-m-sm-on-xl {
    margin: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-m-md-on-xl {
    margin: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-m-lg-on-xl {
    margin: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-m-xl-on-xl {
    margin: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-m-2xl-on-xl {
    margin: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-m-3xl-on-xl {
    margin: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-m-4xl-on-xl {
    margin: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mt-auto-on-xl {
    margin-block-start: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mt-0-on-xl {
    margin-block-start: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mt-xs-on-xl {
    margin-block-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mt-sm-on-xl {
    margin-block-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mt-md-on-xl {
    margin-block-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mt-lg-on-xl {
    margin-block-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mt-xl-on-xl {
    margin-block-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mt-2xl-on-xl {
    margin-block-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mt-3xl-on-xl {
    margin-block-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mt-4xl-on-xl {
    margin-block-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mr-auto-on-xl {
    margin-inline-end: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mr-0-on-xl {
    margin-inline-end: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mr-xs-on-xl {
    margin-inline-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mr-sm-on-xl {
    margin-inline-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mr-md-on-xl {
    margin-inline-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mr-lg-on-xl {
    margin-inline-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mr-xl-on-xl {
    margin-inline-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mr-2xl-on-xl {
    margin-inline-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mr-3xl-on-xl {
    margin-inline-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mr-4xl-on-xl {
    margin-inline-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mb-auto-on-xl {
    margin-block-end: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mb-0-on-xl {
    margin-block-end: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mb-xs-on-xl {
    margin-block-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mb-sm-on-xl {
    margin-block-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mb-md-on-xl {
    margin-block-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mb-lg-on-xl {
    margin-block-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mb-xl-on-xl {
    margin-block-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mb-2xl-on-xl {
    margin-block-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mb-3xl-on-xl {
    margin-block-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mb-4xl-on-xl {
    margin-block-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-ml-auto-on-xl {
    margin-inline-start: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-ml-0-on-xl {
    margin-inline-start: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-ml-xs-on-xl {
    margin-inline-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-ml-sm-on-xl {
    margin-inline-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-ml-md-on-xl {
    margin-inline-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-ml-lg-on-xl {
    margin-inline-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-ml-xl-on-xl {
    margin-inline-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-ml-2xl-on-xl {
    margin-inline-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-ml-3xl-on-xl {
    margin-inline-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-ml-4xl-on-xl {
    margin-inline-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mx-auto-on-xl {
    margin-inline: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mx-0-on-xl {
    margin-inline: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mx-xs-on-xl {
    margin-inline: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mx-sm-on-xl {
    margin-inline: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mx-md-on-xl {
    margin-inline: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mx-lg-on-xl {
    margin-inline: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mx-xl-on-xl {
    margin-inline: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mx-2xl-on-xl {
    margin-inline: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mx-3xl-on-xl {
    margin-inline: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-mx-4xl-on-xl {
    margin-inline: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-my-auto-on-xl {
    margin-block: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-my-0-on-xl {
    margin-block: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-my-xs-on-xl {
    margin-block: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-my-sm-on-xl {
    margin-block: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-my-md-on-xl {
    margin-block: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-my-lg-on-xl {
    margin-block: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-my-xl-on-xl {
    margin-block: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-my-2xl-on-xl {
    margin-block: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-my-3xl-on-xl {
    margin-block: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-my-4xl-on-xl {
    margin-block: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-p-auto-on-xl {
    padding: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-p-0-on-xl {
    padding: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-p-xs-on-xl {
    padding: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-p-sm-on-xl {
    padding: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-p-md-on-xl {
    padding: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-p-lg-on-xl {
    padding: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-p-xl-on-xl {
    padding: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-p-2xl-on-xl {
    padding: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-p-3xl-on-xl {
    padding: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-p-4xl-on-xl {
    padding: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pt-auto-on-xl {
    padding-block-start: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pt-0-on-xl {
    padding-block-start: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pt-xs-on-xl {
    padding-block-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pt-sm-on-xl {
    padding-block-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pt-md-on-xl {
    padding-block-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pt-lg-on-xl {
    padding-block-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pt-xl-on-xl {
    padding-block-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pt-2xl-on-xl {
    padding-block-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pt-3xl-on-xl {
    padding-block-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pt-4xl-on-xl {
    padding-block-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pr-auto-on-xl {
    padding-inline-end: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pr-0-on-xl {
    padding-inline-end: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pr-xs-on-xl {
    padding-inline-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pr-sm-on-xl {
    padding-inline-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pr-md-on-xl {
    padding-inline-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pr-lg-on-xl {
    padding-inline-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pr-xl-on-xl {
    padding-inline-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pr-2xl-on-xl {
    padding-inline-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pr-3xl-on-xl {
    padding-inline-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pr-4xl-on-xl {
    padding-inline-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pb-auto-on-xl {
    padding-block-end: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pb-0-on-xl {
    padding-block-end: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pb-xs-on-xl {
    padding-block-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pb-sm-on-xl {
    padding-block-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pb-md-on-xl {
    padding-block-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pb-lg-on-xl {
    padding-block-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pb-xl-on-xl {
    padding-block-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pb-2xl-on-xl {
    padding-block-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pb-3xl-on-xl {
    padding-block-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pb-4xl-on-xl {
    padding-block-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pl-auto-on-xl {
    padding-inline-start: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pl-0-on-xl {
    padding-inline-start: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pl-xs-on-xl {
    padding-inline-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pl-sm-on-xl {
    padding-inline-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pl-md-on-xl {
    padding-inline-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pl-lg-on-xl {
    padding-inline-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pl-xl-on-xl {
    padding-inline-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pl-2xl-on-xl {
    padding-inline-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pl-3xl-on-xl {
    padding-inline-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-pl-4xl-on-xl {
    padding-inline-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-px-auto-on-xl {
    padding-inline: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-px-0-on-xl {
    padding-inline: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-px-xs-on-xl {
    padding-inline: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-px-sm-on-xl {
    padding-inline: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-px-md-on-xl {
    padding-inline: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-px-lg-on-xl {
    padding-inline: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-px-xl-on-xl {
    padding-inline: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-px-2xl-on-xl {
    padding-inline: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-px-3xl-on-xl {
    padding-inline: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-px-4xl-on-xl {
    padding-inline: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-py-auto-on-xl {
    padding-block: auto !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-py-0-on-xl {
    padding-block: 0 !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-py-xs-on-xl {
    padding-block: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-py-sm-on-xl {
    padding-block: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-py-md-on-xl {
    padding-block: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-py-lg-on-xl {
    padding-block: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-py-xl-on-xl {
    padding-block: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-py-2xl-on-xl {
    padding-block: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-py-3xl-on-xl {
    padding-block: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 75rem) {
  .pf-v6-u-py-4xl-on-xl {
    padding-block: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-m-auto-on-2xl {
    margin: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-m-0-on-2xl {
    margin: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-m-xs-on-2xl {
    margin: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-m-sm-on-2xl {
    margin: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-m-md-on-2xl {
    margin: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-m-lg-on-2xl {
    margin: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-m-xl-on-2xl {
    margin: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-m-2xl-on-2xl {
    margin: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-m-3xl-on-2xl {
    margin: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-m-4xl-on-2xl {
    margin: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mt-auto-on-2xl {
    margin-block-start: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mt-0-on-2xl {
    margin-block-start: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mt-xs-on-2xl {
    margin-block-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mt-sm-on-2xl {
    margin-block-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mt-md-on-2xl {
    margin-block-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mt-lg-on-2xl {
    margin-block-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mt-xl-on-2xl {
    margin-block-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mt-2xl-on-2xl {
    margin-block-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mt-3xl-on-2xl {
    margin-block-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mt-4xl-on-2xl {
    margin-block-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mr-auto-on-2xl {
    margin-inline-end: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mr-0-on-2xl {
    margin-inline-end: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mr-xs-on-2xl {
    margin-inline-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mr-sm-on-2xl {
    margin-inline-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mr-md-on-2xl {
    margin-inline-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mr-lg-on-2xl {
    margin-inline-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mr-xl-on-2xl {
    margin-inline-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mr-2xl-on-2xl {
    margin-inline-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mr-3xl-on-2xl {
    margin-inline-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mr-4xl-on-2xl {
    margin-inline-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mb-auto-on-2xl {
    margin-block-end: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mb-0-on-2xl {
    margin-block-end: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mb-xs-on-2xl {
    margin-block-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mb-sm-on-2xl {
    margin-block-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mb-md-on-2xl {
    margin-block-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mb-lg-on-2xl {
    margin-block-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mb-xl-on-2xl {
    margin-block-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mb-2xl-on-2xl {
    margin-block-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mb-3xl-on-2xl {
    margin-block-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mb-4xl-on-2xl {
    margin-block-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-ml-auto-on-2xl {
    margin-inline-start: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-ml-0-on-2xl {
    margin-inline-start: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-ml-xs-on-2xl {
    margin-inline-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-ml-sm-on-2xl {
    margin-inline-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-ml-md-on-2xl {
    margin-inline-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-ml-lg-on-2xl {
    margin-inline-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-ml-xl-on-2xl {
    margin-inline-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-ml-2xl-on-2xl {
    margin-inline-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-ml-3xl-on-2xl {
    margin-inline-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-ml-4xl-on-2xl {
    margin-inline-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mx-auto-on-2xl {
    margin-inline: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mx-0-on-2xl {
    margin-inline: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mx-xs-on-2xl {
    margin-inline: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mx-sm-on-2xl {
    margin-inline: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mx-md-on-2xl {
    margin-inline: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mx-lg-on-2xl {
    margin-inline: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mx-xl-on-2xl {
    margin-inline: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mx-2xl-on-2xl {
    margin-inline: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mx-3xl-on-2xl {
    margin-inline: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-mx-4xl-on-2xl {
    margin-inline: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-my-auto-on-2xl {
    margin-block: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-my-0-on-2xl {
    margin-block: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-my-xs-on-2xl {
    margin-block: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-my-sm-on-2xl {
    margin-block: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-my-md-on-2xl {
    margin-block: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-my-lg-on-2xl {
    margin-block: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-my-xl-on-2xl {
    margin-block: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-my-2xl-on-2xl {
    margin-block: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-my-3xl-on-2xl {
    margin-block: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-my-4xl-on-2xl {
    margin-block: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-p-auto-on-2xl {
    padding: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-p-0-on-2xl {
    padding: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-p-xs-on-2xl {
    padding: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-p-sm-on-2xl {
    padding: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-p-md-on-2xl {
    padding: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-p-lg-on-2xl {
    padding: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-p-xl-on-2xl {
    padding: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-p-2xl-on-2xl {
    padding: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-p-3xl-on-2xl {
    padding: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-p-4xl-on-2xl {
    padding: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pt-auto-on-2xl {
    padding-block-start: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pt-0-on-2xl {
    padding-block-start: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pt-xs-on-2xl {
    padding-block-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pt-sm-on-2xl {
    padding-block-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pt-md-on-2xl {
    padding-block-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pt-lg-on-2xl {
    padding-block-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pt-xl-on-2xl {
    padding-block-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pt-2xl-on-2xl {
    padding-block-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pt-3xl-on-2xl {
    padding-block-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pt-4xl-on-2xl {
    padding-block-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pr-auto-on-2xl {
    padding-inline-end: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pr-0-on-2xl {
    padding-inline-end: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pr-xs-on-2xl {
    padding-inline-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pr-sm-on-2xl {
    padding-inline-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pr-md-on-2xl {
    padding-inline-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pr-lg-on-2xl {
    padding-inline-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pr-xl-on-2xl {
    padding-inline-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pr-2xl-on-2xl {
    padding-inline-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pr-3xl-on-2xl {
    padding-inline-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pr-4xl-on-2xl {
    padding-inline-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pb-auto-on-2xl {
    padding-block-end: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pb-0-on-2xl {
    padding-block-end: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pb-xs-on-2xl {
    padding-block-end: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pb-sm-on-2xl {
    padding-block-end: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pb-md-on-2xl {
    padding-block-end: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pb-lg-on-2xl {
    padding-block-end: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pb-xl-on-2xl {
    padding-block-end: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pb-2xl-on-2xl {
    padding-block-end: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pb-3xl-on-2xl {
    padding-block-end: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pb-4xl-on-2xl {
    padding-block-end: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pl-auto-on-2xl {
    padding-inline-start: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pl-0-on-2xl {
    padding-inline-start: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pl-xs-on-2xl {
    padding-inline-start: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pl-sm-on-2xl {
    padding-inline-start: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pl-md-on-2xl {
    padding-inline-start: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pl-lg-on-2xl {
    padding-inline-start: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pl-xl-on-2xl {
    padding-inline-start: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pl-2xl-on-2xl {
    padding-inline-start: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pl-3xl-on-2xl {
    padding-inline-start: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-pl-4xl-on-2xl {
    padding-inline-start: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-px-auto-on-2xl {
    padding-inline: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-px-0-on-2xl {
    padding-inline: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-px-xs-on-2xl {
    padding-inline: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-px-sm-on-2xl {
    padding-inline: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-px-md-on-2xl {
    padding-inline: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-px-lg-on-2xl {
    padding-inline: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-px-xl-on-2xl {
    padding-inline: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-px-2xl-on-2xl {
    padding-inline: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-px-3xl-on-2xl {
    padding-inline: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-px-4xl-on-2xl {
    padding-inline: var(--pf-t--global--spacer--4xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-py-auto-on-2xl {
    padding-block: auto !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-py-0-on-2xl {
    padding-block: 0 !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-py-xs-on-2xl {
    padding-block: var(--pf-t--global--spacer--xs) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-py-sm-on-2xl {
    padding-block: var(--pf-t--global--spacer--sm) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-py-md-on-2xl {
    padding-block: var(--pf-t--global--spacer--md) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-py-lg-on-2xl {
    padding-block: var(--pf-t--global--spacer--lg) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-py-xl-on-2xl {
    padding-block: var(--pf-t--global--spacer--xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-py-2xl-on-2xl {
    padding-block: var(--pf-t--global--spacer--2xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-py-3xl-on-2xl {
    padding-block: var(--pf-t--global--spacer--3xl) !important;
  }
}

@media screen and (min-width: 90.625rem) {
  .pf-v6-u-py-4xl-on-2xl {
    padding-block: var(--pf-t--global--spacer--4xl) !important;
  }
}

.pf-v6-u-font-family-text {
  font-family: var(--pf-t--global--font--family--body) !important;
}

.pf-v6-u-font-family-heading {
  font-family: var(--pf-t--global--font--family--heading) !important;
}

.pf-v6-u-font-family-monospace {
  font-family: var(--pf-t--global--font--family--mono) !important;
}

.pf-v6-u-font-size-xs {
  font-size: var(--pf-t--global--font--size--xs) !important;
}

.pf-v6-u-font-size-sm {
  font-size: var(--pf-t--global--font--size--sm) !important;
}

.pf-v6-u-font-size-md {
  font-size: var(--pf-t--global--font--size--md) !important;
}

.pf-v6-u-font-size-lg {
  font-size: var(--pf-t--global--font--size--lg) !important;
}

.pf-v6-u-font-size-xl {
  font-size: var(--pf-t--global--font--size--xl) !important;
}

.pf-v6-u-font-size-2xl {
  font-size: var(--pf-t--global--font--size--2xl) !important;
}

.pf-v6-u-font-size-3xl {
  font-size: var(--pf-t--global--font--size--3xl) !important;
}

.pf-v6-u-font-size-4xl {
  font-size: var(--pf-t--global--font--size--4xl) !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-font-size-xs-on-sm {
    font-size: var(--pf-t--global--font--size--xs) !important;
  }
  .pf-v6-u-font-size-sm-on-sm {
    font-size: var(--pf-t--global--font--size--sm) !important;
  }
  .pf-v6-u-font-size-md-on-sm {
    font-size: var(--pf-t--global--font--size--md) !important;
  }
  .pf-v6-u-font-size-lg-on-sm {
    font-size: var(--pf-t--global--font--size--lg) !important;
  }
  .pf-v6-u-font-size-xl-on-sm {
    font-size: var(--pf-t--global--font--size--xl) !important;
  }
  .pf-v6-u-font-size-2xl-on-sm {
    font-size: var(--pf-t--global--font--size--2xl) !important;
  }
  .pf-v6-u-font-size-3xl-on-sm {
    font-size: var(--pf-t--global--font--size--3xl) !important;
  }
  .pf-v6-u-font-size-4xl-on-sm {
    font-size: var(--pf-t--global--font--size--4xl) !important;
  }
}
@media screen and (min-width: 48rem) {
  .pf-v6-u-font-size-xs-on-md {
    font-size: var(--pf-t--global--font--size--xs) !important;
  }
  .pf-v6-u-font-size-sm-on-md {
    font-size: var(--pf-t--global--font--size--sm) !important;
  }
  .pf-v6-u-font-size-md-on-md {
    font-size: var(--pf-t--global--font--size--md) !important;
  }
  .pf-v6-u-font-size-lg-on-md {
    font-size: var(--pf-t--global--font--size--lg) !important;
  }
  .pf-v6-u-font-size-xl-on-md {
    font-size: var(--pf-t--global--font--size--xl) !important;
  }
  .pf-v6-u-font-size-2xl-on-md {
    font-size: var(--pf-t--global--font--size--2xl) !important;
  }
  .pf-v6-u-font-size-3xl-on-md {
    font-size: var(--pf-t--global--font--size--3xl) !important;
  }
  .pf-v6-u-font-size-4xl-on-md {
    font-size: var(--pf-t--global--font--size--4xl) !important;
  }
}
@media screen and (min-width: 62rem) {
  .pf-v6-u-font-size-xs-on-lg {
    font-size: var(--pf-t--global--font--size--xs) !important;
  }
  .pf-v6-u-font-size-sm-on-lg {
    font-size: var(--pf-t--global--font--size--sm) !important;
  }
  .pf-v6-u-font-size-md-on-lg {
    font-size: var(--pf-t--global--font--size--md) !important;
  }
  .pf-v6-u-font-size-lg-on-lg {
    font-size: var(--pf-t--global--font--size--lg) !important;
  }
  .pf-v6-u-font-size-xl-on-lg {
    font-size: var(--pf-t--global--font--size--xl) !important;
  }
  .pf-v6-u-font-size-2xl-on-lg {
    font-size: var(--pf-t--global--font--size--2xl) !important;
  }
  .pf-v6-u-font-size-3xl-on-lg {
    font-size: var(--pf-t--global--font--size--3xl) !important;
  }
  .pf-v6-u-font-size-4xl-on-lg {
    font-size: var(--pf-t--global--font--size--4xl) !important;
  }
}
@media screen and (min-width: 75rem) {
  .pf-v6-u-font-size-xs-on-xl {
    font-size: var(--pf-t--global--font--size--xs) !important;
  }
  .pf-v6-u-font-size-sm-on-xl {
    font-size: var(--pf-t--global--font--size--sm) !important;
  }
  .pf-v6-u-font-size-md-on-xl {
    font-size: var(--pf-t--global--font--size--md) !important;
  }
  .pf-v6-u-font-size-lg-on-xl {
    font-size: var(--pf-t--global--font--size--lg) !important;
  }
  .pf-v6-u-font-size-xl-on-xl {
    font-size: var(--pf-t--global--font--size--xl) !important;
  }
  .pf-v6-u-font-size-2xl-on-xl {
    font-size: var(--pf-t--global--font--size--2xl) !important;
  }
  .pf-v6-u-font-size-3xl-on-xl {
    font-size: var(--pf-t--global--font--size--3xl) !important;
  }
  .pf-v6-u-font-size-4xl-on-xl {
    font-size: var(--pf-t--global--font--size--4xl) !important;
  }
}
@media screen and (min-width: 90.625rem) {
  .pf-v6-u-font-size-xs-on-2xl {
    font-size: var(--pf-t--global--font--size--xs) !important;
  }
  .pf-v6-u-font-size-sm-on-2xl {
    font-size: var(--pf-t--global--font--size--sm) !important;
  }
  .pf-v6-u-font-size-md-on-2xl {
    font-size: var(--pf-t--global--font--size--md) !important;
  }
  .pf-v6-u-font-size-lg-on-2xl {
    font-size: var(--pf-t--global--font--size--lg) !important;
  }
  .pf-v6-u-font-size-xl-on-2xl {
    font-size: var(--pf-t--global--font--size--xl) !important;
  }
  .pf-v6-u-font-size-2xl-on-2xl {
    font-size: var(--pf-t--global--font--size--2xl) !important;
  }
  .pf-v6-u-font-size-3xl-on-2xl {
    font-size: var(--pf-t--global--font--size--3xl) !important;
  }
  .pf-v6-u-font-size-4xl-on-2xl {
    font-size: var(--pf-t--global--font--size--4xl) !important;
  }
}
.pf-v6-u-font-weight-normal {
  font-weight: var(--pf-t--global--font--weight--body--default) !important;
}

.pf-v6-u-font-weight-bold {
  font-weight: var(--pf-t--global--font--weight--body--bold) !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-font-weight-normal-on-sm {
    font-weight: var(--pf-t--global--font--weight--body--default) !important;
  }
  .pf-v6-u-font-weight-bold-on-sm {
    font-weight: var(--pf-t--global--font--weight--body--bold) !important;
  }
}
@media screen and (min-width: 48rem) {
  .pf-v6-u-font-weight-normal-on-md {
    font-weight: var(--pf-t--global--font--weight--body--default) !important;
  }
  .pf-v6-u-font-weight-bold-on-md {
    font-weight: var(--pf-t--global--font--weight--body--bold) !important;
  }
}
@media screen and (min-width: 62rem) {
  .pf-v6-u-font-weight-normal-on-lg {
    font-weight: var(--pf-t--global--font--weight--body--default) !important;
  }
  .pf-v6-u-font-weight-bold-on-lg {
    font-weight: var(--pf-t--global--font--weight--body--bold) !important;
  }
}
@media screen and (min-width: 75rem) {
  .pf-v6-u-font-weight-normal-on-xl {
    font-weight: var(--pf-t--global--font--weight--body--default) !important;
  }
  .pf-v6-u-font-weight-bold-on-xl {
    font-weight: var(--pf-t--global--font--weight--body--bold) !important;
  }
}
@media screen and (min-width: 90.625rem) {
  .pf-v6-u-font-weight-normal-on-2xl {
    font-weight: var(--pf-t--global--font--weight--body--default) !important;
  }
  .pf-v6-u-font-weight-bold-on-2xl {
    font-weight: var(--pf-t--global--font--weight--body--bold) !important;
  }
}
.pf-v6-u-text-color-brand {
  color: var(--pf-t--global--text--color--brand--default) !important;
}

.pf-v6-u-text-color-disabled {
  color: var(--pf-t--global--text--color--disabled) !important;
}

.pf-v6-u-text-color-on-disabled {
  color: var(--pf-t--global--text--color--on-disabled) !important;
}

.pf-v6-u-text-color-link {
  color: var(--pf-t--global--text--color--link--default) !important;
}

.pf-v6-u-text-color-link-hover {
  color: var(--pf-t--global--text--color--link--hover) !important;
}

.pf-v6-u-text-color-link-visited {
  color: var(--pf-t--global--text--color--link--visited) !important;
}

.pf-v6-u-text-color-placeholder {
  color: var(--pf-t--global--text--color--placeholder) !important;
}

.pf-v6-u-text-color-regular {
  color: var(--pf-t--global--text--color--regular) !important;
}

.pf-v6-u-text-color-required {
  color: var(--pf-t--global--text--color--required) !important;
}

.pf-v6-u-text-color-subtle {
  color: var(--pf-t--global--text--color--subtle) !important;
}

.pf-v6-u-text-color-inverse {
  color: var(--pf-t--global--text--color--inverse) !important;
}

.pf-v6-u-text-color-status-success {
  color: var(--pf-t--global--color--status--success--default) !important;
}

.pf-v6-u-text-color-status-warning {
  color: var(--pf-t--global--text--color--status--warning--default) !important;
}

.pf-v6-u-text-color-status-danger {
  color: var(--pf-t--global--text--color--status--danger--default) !important;
}

.pf-v6-u-text-color-status-default {
  color: var(--pf-t--global--text--color--status--info--default) !important;
}

.pf-v6-u-text-color-status-custom {
  color: var(--pf-t--global--text--color--status--custom--default) !important;
}

.pf-v6-u-icon-color-regular {
  color: var(--pf-t--global--icon--color--regular) !important;
}

.pf-v6-u-icon-color-disabled {
  color: var(--pf-t--global--icon--color--disabled) !important;
}

.pf-v6-u-icon-color-on-disabled {
  color: var(--pf-t--global--icon--color--on-disabled) !important;
}

.pf-v6-u-icon-color-subtle {
  color: var(--pf-t--global--icon--color--subtle) !important;
}

.pf-v6-u-icon-color-inverse {
  color: var(--pf-t--global--icon--color--inverse) !important;
}

.pf-v6-u-icon-color-brand {
  color: var(--pf-t--global--icon--color--brand--default) !important;
}

.pf-v6-u-icon-color-favorite {
  color: var(--pf-t--global--icon--color--favorite--default) !important;
}

.pf-v6-u-icon-color-status-success {
  color: var(--pf-t--global--icon--color--status--success--default) !important;
}

.pf-v6-u-icon-color-status-warning {
  color: var(--pf-t--global--icon--color--status--warning--default) !important;
}

.pf-v6-u-icon-color-status-danger {
  color: var(--pf-t--global--icon--color--status--danger--default) !important;
}

.pf-v6-u-icon-color-status-info {
  color: var(--pf-t--global--icon--color--status--info--default) !important;
}

.pf-v6-u-icon-color-status-custom {
  color: var(--pf-t--global--icon--color--status--custom--default) !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-text-color-brand-on-sm {
    color: var(--pf-t--global--text--color--brand--default) !important;
  }
  .pf-v6-u-text-color-disabled-on-sm {
    color: var(--pf-t--global--text--color--disabled) !important;
  }
  .pf-v6-u-text-color-on-disabled-on-sm {
    color: var(--pf-t--global--text--color--on-disabled) !important;
  }
  .pf-v6-u-text-color-link-on-sm {
    color: var(--pf-t--global--text--color--link--default) !important;
  }
  .pf-v6-u-text-color-link-hover-on-sm {
    color: var(--pf-t--global--text--color--link--hover) !important;
  }
  .pf-v6-u-text-color-link-visited-on-sm {
    color: var(--pf-t--global--text--color--link--visited) !important;
  }
  .pf-v6-u-text-color-placeholder-on-sm {
    color: var(--pf-t--global--text--color--placeholder) !important;
  }
  .pf-v6-u-text-color-regular-on-sm {
    color: var(--pf-t--global--text--color--regular) !important;
  }
  .pf-v6-u-text-color-required-on-sm {
    color: var(--pf-t--global--text--color--required) !important;
  }
  .pf-v6-u-text-color-subtle-on-sm {
    color: var(--pf-t--global--text--color--subtle) !important;
  }
  .pf-v6-u-text-color-inverse-on-sm {
    color: var(--pf-t--global--text--color--inverse) !important;
  }
  .pf-v6-u-text-color-status-success-on-sm {
    color: var(--pf-t--global--color--status--success--default) !important;
  }
  .pf-v6-u-text-color-status-warning-on-sm {
    color: var(--pf-t--global--text--color--status--warning--default) !important;
  }
  .pf-v6-u-text-color-status-danger-on-sm {
    color: var(--pf-t--global--text--color--status--danger--default) !important;
  }
  .pf-v6-u-text-color-status-default-on-sm {
    color: var(--pf-t--global--text--color--status--info--default) !important;
  }
  .pf-v6-u-text-color-status-custom-on-sm {
    color: var(--pf-t--global--text--color--status--custom--default) !important;
  }
  .pf-v6-u-icon-color-regular-on-sm {
    color: var(--pf-t--global--icon--color--regular) !important;
  }
  .pf-v6-u-icon-color-disabled-on-sm {
    color: var(--pf-t--global--icon--color--disabled) !important;
  }
  .pf-v6-u-icon-color-on-disabled-on-sm {
    color: var(--pf-t--global--icon--color--on-disabled) !important;
  }
  .pf-v6-u-icon-color-subtle-on-sm {
    color: var(--pf-t--global--icon--color--subtle) !important;
  }
  .pf-v6-u-icon-color-inverse-on-sm {
    color: var(--pf-t--global--icon--color--inverse) !important;
  }
  .pf-v6-u-icon-color-brand-on-sm {
    color: var(--pf-t--global--icon--color--brand--default) !important;
  }
  .pf-v6-u-icon-color-favorite-on-sm {
    color: var(--pf-t--global--icon--color--favorite--default) !important;
  }
  .pf-v6-u-icon-color-status-success-on-sm {
    color: var(--pf-t--global--icon--color--status--success--default) !important;
  }
  .pf-v6-u-icon-color-status-warning-on-sm {
    color: var(--pf-t--global--icon--color--status--warning--default) !important;
  }
  .pf-v6-u-icon-color-status-danger-on-sm {
    color: var(--pf-t--global--icon--color--status--danger--default) !important;
  }
  .pf-v6-u-icon-color-status-info-on-sm {
    color: var(--pf-t--global--icon--color--status--info--default) !important;
  }
  .pf-v6-u-icon-color-status-custom-on-sm {
    color: var(--pf-t--global--icon--color--status--custom--default) !important;
  }
}
@media screen and (min-width: 48rem) {
  .pf-v6-u-text-color-brand-on-md {
    color: var(--pf-t--global--text--color--brand--default) !important;
  }
  .pf-v6-u-text-color-disabled-on-md {
    color: var(--pf-t--global--text--color--disabled) !important;
  }
  .pf-v6-u-text-color-on-disabled-on-md {
    color: var(--pf-t--global--text--color--on-disabled) !important;
  }
  .pf-v6-u-text-color-link-on-md {
    color: var(--pf-t--global--text--color--link--default) !important;
  }
  .pf-v6-u-text-color-link-hover-on-md {
    color: var(--pf-t--global--text--color--link--hover) !important;
  }
  .pf-v6-u-text-color-link-visited-on-md {
    color: var(--pf-t--global--text--color--link--visited) !important;
  }
  .pf-v6-u-text-color-placeholder-on-md {
    color: var(--pf-t--global--text--color--placeholder) !important;
  }
  .pf-v6-u-text-color-regular-on-md {
    color: var(--pf-t--global--text--color--regular) !important;
  }
  .pf-v6-u-text-color-required-on-md {
    color: var(--pf-t--global--text--color--required) !important;
  }
  .pf-v6-u-text-color-subtle-on-md {
    color: var(--pf-t--global--text--color--subtle) !important;
  }
  .pf-v6-u-text-color-inverse-on-md {
    color: var(--pf-t--global--text--color--inverse) !important;
  }
  .pf-v6-u-text-color-status-success-on-md {
    color: var(--pf-t--global--color--status--success--default) !important;
  }
  .pf-v6-u-text-color-status-warning-on-md {
    color: var(--pf-t--global--text--color--status--warning--default) !important;
  }
  .pf-v6-u-text-color-status-danger-on-md {
    color: var(--pf-t--global--text--color--status--danger--default) !important;
  }
  .pf-v6-u-text-color-status-default-on-md {
    color: var(--pf-t--global--text--color--status--info--default) !important;
  }
  .pf-v6-u-text-color-status-custom-on-md {
    color: var(--pf-t--global--text--color--status--custom--default) !important;
  }
  .pf-v6-u-icon-color-regular-on-md {
    color: var(--pf-t--global--icon--color--regular) !important;
  }
  .pf-v6-u-icon-color-disabled-on-md {
    color: var(--pf-t--global--icon--color--disabled) !important;
  }
  .pf-v6-u-icon-color-on-disabled-on-md {
    color: var(--pf-t--global--icon--color--on-disabled) !important;
  }
  .pf-v6-u-icon-color-subtle-on-md {
    color: var(--pf-t--global--icon--color--subtle) !important;
  }
  .pf-v6-u-icon-color-inverse-on-md {
    color: var(--pf-t--global--icon--color--inverse) !important;
  }
  .pf-v6-u-icon-color-brand-on-md {
    color: var(--pf-t--global--icon--color--brand--default) !important;
  }
  .pf-v6-u-icon-color-favorite-on-md {
    color: var(--pf-t--global--icon--color--favorite--default) !important;
  }
  .pf-v6-u-icon-color-status-success-on-md {
    color: var(--pf-t--global--icon--color--status--success--default) !important;
  }
  .pf-v6-u-icon-color-status-warning-on-md {
    color: var(--pf-t--global--icon--color--status--warning--default) !important;
  }
  .pf-v6-u-icon-color-status-danger-on-md {
    color: var(--pf-t--global--icon--color--status--danger--default) !important;
  }
  .pf-v6-u-icon-color-status-info-on-md {
    color: var(--pf-t--global--icon--color--status--info--default) !important;
  }
  .pf-v6-u-icon-color-status-custom-on-md {
    color: var(--pf-t--global--icon--color--status--custom--default) !important;
  }
}
@media screen and (min-width: 62rem) {
  .pf-v6-u-text-color-brand-on-lg {
    color: var(--pf-t--global--text--color--brand--default) !important;
  }
  .pf-v6-u-text-color-disabled-on-lg {
    color: var(--pf-t--global--text--color--disabled) !important;
  }
  .pf-v6-u-text-color-on-disabled-on-lg {
    color: var(--pf-t--global--text--color--on-disabled) !important;
  }
  .pf-v6-u-text-color-link-on-lg {
    color: var(--pf-t--global--text--color--link--default) !important;
  }
  .pf-v6-u-text-color-link-hover-on-lg {
    color: var(--pf-t--global--text--color--link--hover) !important;
  }
  .pf-v6-u-text-color-link-visited-on-lg {
    color: var(--pf-t--global--text--color--link--visited) !important;
  }
  .pf-v6-u-text-color-placeholder-on-lg {
    color: var(--pf-t--global--text--color--placeholder) !important;
  }
  .pf-v6-u-text-color-regular-on-lg {
    color: var(--pf-t--global--text--color--regular) !important;
  }
  .pf-v6-u-text-color-required-on-lg {
    color: var(--pf-t--global--text--color--required) !important;
  }
  .pf-v6-u-text-color-subtle-on-lg {
    color: var(--pf-t--global--text--color--subtle) !important;
  }
  .pf-v6-u-text-color-inverse-on-lg {
    color: var(--pf-t--global--text--color--inverse) !important;
  }
  .pf-v6-u-text-color-status-success-on-lg {
    color: var(--pf-t--global--color--status--success--default) !important;
  }
  .pf-v6-u-text-color-status-warning-on-lg {
    color: var(--pf-t--global--text--color--status--warning--default) !important;
  }
  .pf-v6-u-text-color-status-danger-on-lg {
    color: var(--pf-t--global--text--color--status--danger--default) !important;
  }
  .pf-v6-u-text-color-status-default-on-lg {
    color: var(--pf-t--global--text--color--status--info--default) !important;
  }
  .pf-v6-u-text-color-status-custom-on-lg {
    color: var(--pf-t--global--text--color--status--custom--default) !important;
  }
  .pf-v6-u-icon-color-regular-on-lg {
    color: var(--pf-t--global--icon--color--regular) !important;
  }
  .pf-v6-u-icon-color-disabled-on-lg {
    color: var(--pf-t--global--icon--color--disabled) !important;
  }
  .pf-v6-u-icon-color-on-disabled-on-lg {
    color: var(--pf-t--global--icon--color--on-disabled) !important;
  }
  .pf-v6-u-icon-color-subtle-on-lg {
    color: var(--pf-t--global--icon--color--subtle) !important;
  }
  .pf-v6-u-icon-color-inverse-on-lg {
    color: var(--pf-t--global--icon--color--inverse) !important;
  }
  .pf-v6-u-icon-color-brand-on-lg {
    color: var(--pf-t--global--icon--color--brand--default) !important;
  }
  .pf-v6-u-icon-color-favorite-on-lg {
    color: var(--pf-t--global--icon--color--favorite--default) !important;
  }
  .pf-v6-u-icon-color-status-success-on-lg {
    color: var(--pf-t--global--icon--color--status--success--default) !important;
  }
  .pf-v6-u-icon-color-status-warning-on-lg {
    color: var(--pf-t--global--icon--color--status--warning--default) !important;
  }
  .pf-v6-u-icon-color-status-danger-on-lg {
    color: var(--pf-t--global--icon--color--status--danger--default) !important;
  }
  .pf-v6-u-icon-color-status-info-on-lg {
    color: var(--pf-t--global--icon--color--status--info--default) !important;
  }
  .pf-v6-u-icon-color-status-custom-on-lg {
    color: var(--pf-t--global--icon--color--status--custom--default) !important;
  }
}
@media screen and (min-width: 75rem) {
  .pf-v6-u-text-color-brand-on-xl {
    color: var(--pf-t--global--text--color--brand--default) !important;
  }
  .pf-v6-u-text-color-disabled-on-xl {
    color: var(--pf-t--global--text--color--disabled) !important;
  }
  .pf-v6-u-text-color-on-disabled-on-xl {
    color: var(--pf-t--global--text--color--on-disabled) !important;
  }
  .pf-v6-u-text-color-link-on-xl {
    color: var(--pf-t--global--text--color--link--default) !important;
  }
  .pf-v6-u-text-color-link-hover-on-xl {
    color: var(--pf-t--global--text--color--link--hover) !important;
  }
  .pf-v6-u-text-color-link-visited-on-xl {
    color: var(--pf-t--global--text--color--link--visited) !important;
  }
  .pf-v6-u-text-color-placeholder-on-xl {
    color: var(--pf-t--global--text--color--placeholder) !important;
  }
  .pf-v6-u-text-color-regular-on-xl {
    color: var(--pf-t--global--text--color--regular) !important;
  }
  .pf-v6-u-text-color-required-on-xl {
    color: var(--pf-t--global--text--color--required) !important;
  }
  .pf-v6-u-text-color-subtle-on-xl {
    color: var(--pf-t--global--text--color--subtle) !important;
  }
  .pf-v6-u-text-color-inverse-on-xl {
    color: var(--pf-t--global--text--color--inverse) !important;
  }
  .pf-v6-u-text-color-status-success-on-xl {
    color: var(--pf-t--global--color--status--success--default) !important;
  }
  .pf-v6-u-text-color-status-warning-on-xl {
    color: var(--pf-t--global--text--color--status--warning--default) !important;
  }
  .pf-v6-u-text-color-status-danger-on-xl {
    color: var(--pf-t--global--text--color--status--danger--default) !important;
  }
  .pf-v6-u-text-color-status-default-on-xl {
    color: var(--pf-t--global--text--color--status--info--default) !important;
  }
  .pf-v6-u-text-color-status-custom-on-xl {
    color: var(--pf-t--global--text--color--status--custom--default) !important;
  }
  .pf-v6-u-icon-color-regular-on-xl {
    color: var(--pf-t--global--icon--color--regular) !important;
  }
  .pf-v6-u-icon-color-disabled-on-xl {
    color: var(--pf-t--global--icon--color--disabled) !important;
  }
  .pf-v6-u-icon-color-on-disabled-on-xl {
    color: var(--pf-t--global--icon--color--on-disabled) !important;
  }
  .pf-v6-u-icon-color-subtle-on-xl {
    color: var(--pf-t--global--icon--color--subtle) !important;
  }
  .pf-v6-u-icon-color-inverse-on-xl {
    color: var(--pf-t--global--icon--color--inverse) !important;
  }
  .pf-v6-u-icon-color-brand-on-xl {
    color: var(--pf-t--global--icon--color--brand--default) !important;
  }
  .pf-v6-u-icon-color-favorite-on-xl {
    color: var(--pf-t--global--icon--color--favorite--default) !important;
  }
  .pf-v6-u-icon-color-status-success-on-xl {
    color: var(--pf-t--global--icon--color--status--success--default) !important;
  }
  .pf-v6-u-icon-color-status-warning-on-xl {
    color: var(--pf-t--global--icon--color--status--warning--default) !important;
  }
  .pf-v6-u-icon-color-status-danger-on-xl {
    color: var(--pf-t--global--icon--color--status--danger--default) !important;
  }
  .pf-v6-u-icon-color-status-info-on-xl {
    color: var(--pf-t--global--icon--color--status--info--default) !important;
  }
  .pf-v6-u-icon-color-status-custom-on-xl {
    color: var(--pf-t--global--icon--color--status--custom--default) !important;
  }
}
@media screen and (min-width: 90.625rem) {
  .pf-v6-u-text-color-brand-on-2xl {
    color: var(--pf-t--global--text--color--brand--default) !important;
  }
  .pf-v6-u-text-color-disabled-on-2xl {
    color: var(--pf-t--global--text--color--disabled) !important;
  }
  .pf-v6-u-text-color-on-disabled-on-2xl {
    color: var(--pf-t--global--text--color--on-disabled) !important;
  }
  .pf-v6-u-text-color-link-on-2xl {
    color: var(--pf-t--global--text--color--link--default) !important;
  }
  .pf-v6-u-text-color-link-hover-on-2xl {
    color: var(--pf-t--global--text--color--link--hover) !important;
  }
  .pf-v6-u-text-color-link-visited-on-2xl {
    color: var(--pf-t--global--text--color--link--visited) !important;
  }
  .pf-v6-u-text-color-placeholder-on-2xl {
    color: var(--pf-t--global--text--color--placeholder) !important;
  }
  .pf-v6-u-text-color-regular-on-2xl {
    color: var(--pf-t--global--text--color--regular) !important;
  }
  .pf-v6-u-text-color-required-on-2xl {
    color: var(--pf-t--global--text--color--required) !important;
  }
  .pf-v6-u-text-color-subtle-on-2xl {
    color: var(--pf-t--global--text--color--subtle) !important;
  }
  .pf-v6-u-text-color-inverse-on-2xl {
    color: var(--pf-t--global--text--color--inverse) !important;
  }
  .pf-v6-u-text-color-status-success-on-2xl {
    color: var(--pf-t--global--color--status--success--default) !important;
  }
  .pf-v6-u-text-color-status-warning-on-2xl {
    color: var(--pf-t--global--text--color--status--warning--default) !important;
  }
  .pf-v6-u-text-color-status-danger-on-2xl {
    color: var(--pf-t--global--text--color--status--danger--default) !important;
  }
  .pf-v6-u-text-color-status-default-on-2xl {
    color: var(--pf-t--global--text--color--status--info--default) !important;
  }
  .pf-v6-u-text-color-status-custom-on-2xl {
    color: var(--pf-t--global--text--color--status--custom--default) !important;
  }
  .pf-v6-u-icon-color-regular-on-2xl {
    color: var(--pf-t--global--icon--color--regular) !important;
  }
  .pf-v6-u-icon-color-disabled-on-2xl {
    color: var(--pf-t--global--icon--color--disabled) !important;
  }
  .pf-v6-u-icon-color-on-disabled-on-2xl {
    color: var(--pf-t--global--icon--color--on-disabled) !important;
  }
  .pf-v6-u-icon-color-subtle-on-2xl {
    color: var(--pf-t--global--icon--color--subtle) !important;
  }
  .pf-v6-u-icon-color-inverse-on-2xl {
    color: var(--pf-t--global--icon--color--inverse) !important;
  }
  .pf-v6-u-icon-color-brand-on-2xl {
    color: var(--pf-t--global--icon--color--brand--default) !important;
  }
  .pf-v6-u-icon-color-favorite-on-2xl {
    color: var(--pf-t--global--icon--color--favorite--default) !important;
  }
  .pf-v6-u-icon-color-status-success-on-2xl {
    color: var(--pf-t--global--icon--color--status--success--default) !important;
  }
  .pf-v6-u-icon-color-status-warning-on-2xl {
    color: var(--pf-t--global--icon--color--status--warning--default) !important;
  }
  .pf-v6-u-icon-color-status-danger-on-2xl {
    color: var(--pf-t--global--icon--color--status--danger--default) !important;
  }
  .pf-v6-u-icon-color-status-info-on-2xl {
    color: var(--pf-t--global--icon--color--status--info--default) !important;
  }
  .pf-v6-u-icon-color-status-custom-on-2xl {
    color: var(--pf-t--global--icon--color--status--custom--default) !important;
  }
}
.pf-v6-u-text-break-word {
  word-break: break-word !important;
}

.pf-v6-u-text-nowrap {
  white-space: nowrap !important;
}

.pf-v6-u-text-wrap {
  white-space: normal !important;
}

@media screen and (min-width: 36rem) {
  .pf-v6-u-text-break-word-on-sm {
    word-break: break-word !important;
  }
  .pf-v6-u-text-nowrap-on-sm {
    white-space: nowrap !important;
  }
  .pf-v6-u-text-wrap-on-sm {
    white-space: normal !important;
  }
}
@media screen and (min-width: 48rem) {
  .pf-v6-u-text-break-word-on-md {
    word-break: break-word !important;
  }
  .pf-v6-u-text-nowrap-on-md {
    white-space: nowrap !important;
  }
  .pf-v6-u-text-wrap-on-md {
    white-space: normal !important;
  }
}
@media screen and (min-width: 62rem) {
  .pf-v6-u-text-break-word-on-lg {
    word-break: break-word !important;
  }
  .pf-v6-u-text-nowrap-on-lg {
    white-space: nowrap !important;
  }
  .pf-v6-u-text-wrap-on-lg {
    white-space: normal !important;
  }
}
@media screen and (min-width: 75rem) {
  .pf-v6-u-text-break-word-on-xl {
    word-break: break-word !important;
  }
  .pf-v6-u-text-nowrap-on-xl {
    white-space: nowrap !important;
  }
  .pf-v6-u-text-wrap-on-xl {
    white-space: normal !important;
  }
}
@media screen and (min-width: 90.625rem) {
  .pf-v6-u-text-break-word-on-2xl {
    word-break: break-word !important;
  }
  .pf-v6-u-text-nowrap-on-2xl {
    white-space: nowrap !important;
  }
  .pf-v6-u-text-wrap-on-2xl {
    white-space: normal !important;
  }
}
.pf-v6-u-text-truncate {
  min-width: 0 !important;
  max-width: 100% !important;
  overflow: hidden !important;
  text-overflow: ellipsis !important;
  white-space: nowrap !important;
}